@@ -110,6 +110,7 @@ Type.copyPrototypeMethods(JXG.Line3D, JXG.GeometryElement3D, 'constructor3D');
 JXG.extend(
     JXG.Line3D.prototype,
     /** @lends JXG.Line3D.prototype */ {
+
         /**
          * Determine one end point of a 3D line from point, direction and range.
          *
@@ -145,6 +146,18 @@ JXG.extend(
             return this;
         },
 
+        setPosition2D: function (t) {
+            var j, el;
+
+            for (j = 0; j < this.parents.length; j++) {
+                // Run through defining 3D points
+                el = this.view.select(this.parents[j]);
+                if (el.elType === 'point3d' && el.element2D.draggable()) {
+                    t.applyOnce(el.element2D);
+                }
+            }
+        },
+
         updateRenderer: function () {
             this.needsUpdate = false;
             return this;
@@ -320,7 +333,8 @@ JXG.createLine3D = function (board, parents, attributes) {
         el.endpoints = endpoints;
         el.addChild(endpoints[0]);
         el.addChild(endpoints[1]);
-        el.setParents(endpoints);
+        // el.setParents(endpoints);
+        el.addParents([point1, point2]);
 
     } else {
         // Line defined by point, direction and range
@@ -382,13 +396,14 @@ JXG.createLine3D = function (board, parents, attributes) {
         el.element2D.view = view;
 
         el.endpoints = points;
+        el.addParents(point);
     }
+
     // TODO Throw error
 
     el.addChild(el.element2D);
     el.inherits.push(el.element2D);
-    el.element2D.setParents(el);
-    // el.setParents([point1.id, point2.id]);
+    el.element2D.addParents(el);
 
     el.point1 = point1;
     el.point2 = point2;
@@ -556,9 +571,20 @@ JXG.extend(
          */
         updateNormal: function () {
             var i, len;
-            for (i = 0; i < 3; i++) {
-                this.vec1[i] = Type.evaluate(this.direction1[i]);
-                this.vec2[i] = Type.evaluate(this.direction2[i]);
+
+            if (Type.isFunction(this.direction1)) {
+                this.vec1 = Type.evaluate(this.direction1);
+            } else {
+                for (i = 0; i < 3; i++) {
+                    this.vec1[i] = Type.evaluate(this.direction1[i]);
+                }
+            }
+            if (Type.isFunction(this.direction2)) {
+                this.vec2 = Type.evaluate(this.direction2);
+            } else {
+                for (i = 0; i < 3; i++) {
+                    this.vec2[i] = Type.evaluate(this.direction2[i]);
+                }
             }
 
             this.normal = Mat.crossProduct(this.vec1, this.vec2);
@@ -576,7 +602,7 @@ JXG.extend(
 
         updateDataArray: function () {
             var s1, e1, s2, e2, c2d, l1, l2,
-                planes = ['xPlaneRear', 'yPlaneRear', 'zPlaneRear'],
+                planes = ['xPlaneRear', 'yPlaneRear', 'zPlaneRear'], // Must be ordered x, y, z
                 points = [],
                 v1 = [0, 0, 0],
                 v2 = [0, 0, 0],
@@ -599,17 +625,20 @@ JXG.extend(
                 Type.evaluate(this.range2[0]) === -Infinity &&
                 Type.evaluate(this.range2[1]) === Infinity
             ) {
+                // Determine the intersections of the new plane with
+                // the view bbox3d.
+                //
                 // Start with the rear plane.
-                // Determine the intersections with the view bbox3d
                 // For each face of the bbox3d we determine two points
-                // which are the ends of the intersection line.
-                // We start with the three rear planes.
+                // which are the end points of the intersecting line
+                // between the plane and a face of bbox3d.
+                // We start with the three rear planes (set in planes[] above)
                 for (j = 0; j < planes.length; j++) {
                     p = view.intersectionPlanePlane(this, view.defaultAxes[planes[j]]);
-
                     if (p[0].length === 3 && p[1].length === 3) {
                         // This test is necessary to filter out intersection lines which are
-                        // identical to intersections of axis planes (they would occur twice).
+                        // identical to intersections of axis planes (they would occur twice),
+                        // i.e. edges of bbox3d.
                         for (i = 0; i < points.length; i++) {
                             if (
                                 (Geometry.distance(p[0], points[i][0], 3) < Mat.eps &&
@@ -625,10 +654,11 @@ JXG.extend(
                         }
                     }
 
-                    // Point on the front plane of the bbox3d
+                    // Take a point on the corresponding front plane of bbox3d.
                     p = [0, 0, 0];
                     p[j] = view.bbox3D[j][1];
 
+                    // Use the Hesse normal form of front plane to intersect it with the plane
                     // d is the rhs of the Hesse normal form of the front plane.
                     d = Mat.innerProduct(p, view.defaultAxes[planes[j]].normal, 3);
                     p = view.intersectionPlanePlane(this, view.defaultAxes[planes[j]], d);
@@ -636,6 +666,7 @@ JXG.extend(
                     if (p[0].length === 3 && p[1].length === 3) {
                         // Do the same test as above
                         for (i = 0; i < points.length; i++) {
+                            // Same test for edges of bbox3d as above
                             if (
                                 (Geometry.distance(p[0], points[i][0], 3) < Mat.eps &&
                                     Geometry.distance(p[1], points[i][1], 3) < Mat.eps) ||
@@ -651,6 +682,11 @@ JXG.extend(
                     }
                 }
 
+                // Handle the case that the plane does not intersect bbox3d at all.
+                if (points.length === 0) {
+                    return { X: this.dataX, Y: this.dataY };
+                }
+
                 // Concatenate the intersection points to a polygon.
                 // If all went well, each intersection should appear
                 // twice in the list.
@@ -862,7 +898,7 @@ JXG.registerElement('plane3d', JXG.createPlane3D);
  * <script type="text/javascript">
  *     (function() {
  *         var board = JXG.JSXGraph.initBoard('JXGdb931076-b29a-4eff-b97e-4251aaf24943',
- *             {boundingbox: [-8, 8, 8,-8], axis: false, showcopyright: false, shownavigation: false});
+ *             {boundingbox: [-8, 8, 8,-8], axis: false, pan: {enabled: false}, showcopyright: false, shownavigation: false});
  *         var view = board.create(
  *             'view3d',
  *             [[-6, -3], [8, 8],
