@@ -209,7 +209,7 @@ JXG.extend(
  * <script type="text/javascript">
  *     (function() {
  *         var board = JXG.JSXGraph.initBoard('JXG52da0ecc-1ba9-4d41-850c-36e5120025a5',
- *             {boundingbox: [-8, 8, 8,-8], axis: false, showcopyright: false, shownavigation: false});
+ *             {boundingbox: [-8, 8, 8,-8], axis: false, pan: {enabled: false}, showcopyright: false, shownavigation: false});
  *     var view = board.create('view3d',
  *            [[-6, -3], [8, 8],
  *            [[-5, 5], [-5, 5], [-5, 5]]]);
@@ -292,7 +292,7 @@ JXG.registerElement("parametricsurface3d", JXG.createParametricSurface3D);
  * @constructor
  * @type Object
  * @throws {Exception} If the element cannot be constructed with the given parent objects an exception is thrown.
- * @param {Function_Array_Array} F,rangeX,rangeY  F(x,y) is a function returning a number, rangeX is the array containing
+ * @param {Function,String_Array_Array} F,rangeX,rangeY  F(x,y) is a function returning a number (or a JessieCode string), rangeX is the array containing
  * lower and upper bound for the range of x, rangeY is the array containing
  * lower and upper bound for the range of y.
  * @example
@@ -325,7 +325,7 @@ JXG.registerElement("parametricsurface3d", JXG.createParametricSurface3D);
  * <script type="text/javascript">
  *     (function() {
  *         var board = JXG.JSXGraph.initBoard('JXG87646dd4-9fe5-4c21-8734-089abc612515',
- *             {boundingbox: [-8, 8, 8,-8], axis: false, showcopyright: false, shownavigation: false});
+ *             {boundingbox: [-8, 8, 8,-8], axis: false, pan: {enabled: false}, showcopyright: false, shownavigation: false});
  *     var box = [-5, 5];
  *     var view = board.create('view3d',
  *         [
@@ -363,7 +363,7 @@ JXG.createFunctiongraph3D = function (board, parents, attributes) {
         Y = function (u, v) {
             return v;
         },
-        Z = parents[1],
+        Z = Type.createFunction(parents[1], board, 'x, y'),
         range_u = parents[2],
         range_v = parents[3];
 
