@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -32,24 +32,24 @@
 /*global JXG: true, define: true, document: true*/
 /*jslint nomen: true, plusplus: true*/
 
-import JXG from "../jxg";
-import Numerics from "../math/numerics";
-import Statistics from "../math/statistics";
-import Const from "./constants";
-import Coords from "./coords";
-import GeometryElement from "./element";
-import DataSource from "../parser/datasource";
-import Color from "../utils/color";
-import Type from "../utils/type";
-import Env from "../utils/env";
-// import Curve from "./curve";
-// import Point from "./point";
-// import Text from "./text";
-// import Polygon from "./polygon";
-// import Sector from "../element/sector";
-// import Transform from "./transformation";
-// import Line from "./line";
-// import Circle from "./circle";
+import JXG from "../jxg.js";
+import Numerics from "../math/numerics.js";
+import Const from "./constants.js";
+import Coords from "./coords.js";
+import GeometryElement from "./element.js";
+import DataSource from "../parser/datasource.js";
+import Color from "../utils/color.js";
+import Type from "../utils/type.js";
+import Env from "../utils/env.js";
+// import Statistics from "../math/statistics.js";
+// import Curve from "./curve.js";
+// import Point from "./point.js";
+// import Text from "./text.js";
+// import Polygon from "./polygon.js";
+// import Sector from "../element/sector.js";
+// import Transform from "./transformation.js";
+// import Line from "./line.js";
+// import Circle from "./circle.js";
 
 /**
  *
@@ -58,7 +58,7 @@ import Env from "../utils/env";
  * Use {@link JXG.Board#create} with type {@link Chart} instead.
  * @constructor
  * @augments JXG.GeometryElement
- * @param {String,JXG.Board} board The board the new chart is drawn on.
+ * @param {String|JXG.Board} board The board the new chart is drawn on.
  * @param {Array} parent data arrays for the chart
  * @param {Object} attributes Javascript object containing attributes like name, id and colors.
  *
@@ -150,7 +150,7 @@ JXG.extend(
         /**
          * Create line chart defined by two data arrays.
          *
-         * @param  {String,JXG.Board} board      The board the chart is drawn on
+         * @param  {String|JXG.Board} board      The board the chart is drawn on
          * @param  {Array} x          Array of x-coordinates
          * @param  {Array} y          Array of y-coordinates
          * @param  {Object} attributes  Javascript object containing attributes like colors
@@ -168,7 +168,7 @@ JXG.extend(
          * Create line chart that consists of a natural spline curve
          * defined by two data arrays.
          *
-         * @param  {String,JXG.Board} board      The board the chart is drawn on
+         * @param  {String|JXG.Board} board      The board the chart is drawn on
          * @param  {Array} x          Array of x-coordinates
          * @param  {Array} y          Array of y-coordinates
          * @param  {Object} attributes Javascript object containing attributes like colors
@@ -187,7 +187,7 @@ JXG.extend(
          * defined by two data arrays. The degree of the polynomial is supplied
          * through the attribute "degree" in attributes.
          *
-         * @param  {String,JXG.Board} board      The board the chart is drawn on
+         * @param  {String|JXG.Board} board      The board the chart is drawn on
          * @param  {Array} x          Array of x-coordinates
          * @param  {Array} y          Array of y-coordinates
          * @param  {Object} attributes Javascript object containing attributes like colors
@@ -219,7 +219,7 @@ JXG.extend(
          * <li> labels: array of labels
          * </ul>
          *
-         * @param  {String,JXG.Board} board      The board the chart is drawn on
+         * @param  {String|JXG.Board} board      The board the chart is drawn on
          * @param  {Array} x          Array of x-coordinates
          * @param  {Array} y          Array of y-coordinates
          * @param  {Object} attributes Javascript object containing attributes like colors
@@ -227,7 +227,6 @@ JXG.extend(
          */
         drawBar: function (board, x, y, attributes) {
             var i,
-                strwidth,
                 text,
                 w,
                 xp0,
@@ -347,7 +346,7 @@ JXG.extend(
          * <li> infoboxArray (Array): Texts for the infobox
          * </ul>
          *
-         * @param  {String,JXG.Board} board      The board the chart is drawn on
+         * @param  {String|JXG.Board} board      The board the chart is drawn on
          * @param  {Array} x          Array of x-coordinates
          * @param  {Array} y          Array of y-coordinates
          * @param  {Object} attributes Javascript object containing attributes like colors
@@ -383,7 +382,7 @@ JXG.extend(
          * <li> highlightOnSector (Boolean)
          * </ul>
          *
-         * @param  {String,JXG.Board} board      The board the chart is drawn on
+         * @param  {String|JXG.Board} board      The board the chart is drawn on
          * @param  {Array} y          Array of x-coordinates
          * @param  {Object} attributes Javascript object containing attributes like colors
          * @returns {Object}  with keys: "{sectors, points, midpoint}"
@@ -393,7 +392,7 @@ JXG.extend(
                 center,
                 p = [],
                 sector = [],
-                s = Statistics.sum(y),
+                // s = Statistics.sum(y),
                 colorArray = attributes.colors,
                 highlightColorArray = attributes.highlightcolors,
                 labelArray = attributes.labels,
@@ -553,7 +552,7 @@ JXG.extend(
          * <li> circleStrokeWidth
          * </ul>
          *
-         * @param  {String,JXG.Board} board      The board the chart is drawn on
+         * @param  {String|JXG.Board} board      The board the chart is drawn on
          * @param  {Array} parents    Array of coordinates, e.g. [[x1, y1, z1], [x2, y2, z2], [x3, y3, z3]]
          * @param  {Object} attributes Javascript object containing attributes like colors
          * @returns {Object} with keys "{circles, lines, points, midpoint, polygons}"
@@ -577,7 +576,7 @@ JXG.extend(
                 ends,
                 labelArray,
                 colorArray,
-                highlightColorArray,
+                // highlightColorArray,
                 radius,
                 myAtts,
                 cent,
@@ -763,7 +762,7 @@ JXG.extend(
             // labels for legend
             labelArray = attributes.labelarray || la;
             colorArray = attributes.colors;
-            highlightColorArray = attributes.highlightcolors;
+            // highlightColorArray = attributes.highlightcolors;
             radius = attributes.radius || 10;
             sw = attributes.strokewidth || 1;
 
@@ -968,7 +967,6 @@ JXG.extend(
 /**
  * @class Constructor for a chart.
  * @pseudo
- * @description
  * @name Chart
  * @augments JXG.Chart
  * @constructor
@@ -1346,7 +1344,7 @@ JXG.registerElement("chart", JXG.createChart);
  * access with the property "lines" of the element.
  * @constructor
  * @augments JXG.GeometryElement
- * @param {String,JXG.Board} board The board the new legend is drawn on.
+ * @param {String|JXG.Board} board The board the new legend is drawn on.
  * @param {Array} coords Coordinates of the left top point of the legend.
  * @param  {Object} attributes Attributes of the legend
  */
@@ -1384,7 +1382,7 @@ JXG.Legend.prototype = new GeometryElement();
  * Draw a vertical legend.
  *
  * @private
- * @param  {String,JXG.Board} board      The board the legend is drawn on
+ * @param  {String|JXG.Board} board      The board the legend is drawn on
  * @param  {Object} attributes Attributes of the legend
  */
 JXG.Legend.prototype.drawVerticalLegend = function (board, attributes) {
@@ -1442,7 +1440,6 @@ JXG.Legend.prototype.drawVerticalLegend = function (board, attributes) {
  * </ul>
  *
  * @pseudo
- * @description
  * @name Legend
  * @augments JXG.Legend
  * @constructor
