@@ -293,7 +293,7 @@ JXG.extend(
                             if (slide === poly.borders[i]) {
                                 slide =
                                     poly.borders[
-                                        (i - 1 + poly.borders.length) % poly.borders.length
+                                    (i - 1 + poly.borders.length) % poly.borders.length
                                     ];
                                 break;
                             }
@@ -303,7 +303,7 @@ JXG.extend(
                             if (slide === poly.borders[i]) {
                                 slide =
                                     poly.borders[
-                                        (i + 1 + poly.borders.length) % poly.borders.length
+                                    (i + 1 + poly.borders.length) % poly.borders.length
                                     ];
                                 break;
                             }
@@ -380,7 +380,7 @@ JXG.extend(
 
                 // Snap the glider to snap values.
                 snappedTo = this.findClosestSnapValue(newPos);
-                if(snappedTo !== null) {
+                if (snappedTo !== null) {
                     snapValues = Type.evaluate(this.visProp.snapvalues);
                     newPos = (snapValues[snappedTo] - this._smin) / (this._smax - this._smin);
                     this.update(true);
@@ -479,6 +479,8 @@ JXG.extend(
                     // Handle the case if the curve comes from a transformation of a continuous curve.
                     if (slide.transformations.length > 0) {
                         isTransformed = false;
+                        // TODO this might buggy, see the recursion
+                        // in line.js getCurveTangentDir
                         res = slide.getTransformationSource();
                         if (res[0]) {
                             isTransformed = res[0];
@@ -553,7 +555,7 @@ JXG.extend(
          * @returns {Number} Index of the value to snap to, or null.
          * @private
          */
-        findClosestSnapValue: function(pos) {
+        findClosestSnapValue: function (pos) {
             var i, d,
                 snapValues, snapValueDistance,
                 snappedTo = null;
@@ -860,7 +862,7 @@ JXG.extend(
          * @param {Boolean} [withZ=false] If set to true the return value will be <tt>(x | y | z)</tt> instead of <tt>(x, y)</tt>.
          * @returns {String} User coordinates of point.
          */
-        Coords: function(withZ) {
+        Coords: function (withZ) {
             if (withZ) {
                 return this.coords.usrCoords.slice();
             }
@@ -1723,6 +1725,20 @@ JXG.extend(
          *     })();
          *
          * </script><pre>
+         * @example
+         * //animate example closed curve
+         * var c1 = board.create('curve',[(u)=>4*Math.cos(u),(u)=>2*Math.sin(u)+2,0,2*Math.PI]);
+         * var p2 = board.create('glider', [c1]);
+         * var button1 = board.create('button', [1, 7, 'start animation',function(){p2.startAnimation(1,8)}]);
+         * var button2 = board.create('button', [1, 5, 'stop animation',function(){p2.stopAnimation()}]);
+         * </pre><div class="jxgbox" id="JXG10e885ea-b05d-4e7d-a473-bac2554bce68" style="width: 200px; height: 200px;"></div>
+         * <script type="text/javascript">
+         *   var gpex4_board = JXG.JSXGraph.initBoard('JXG10e885ea-b05d-4e7d-a473-bac2554bce68', {boundingbox: [-1, 10, 10, -1], axis: true, showcopyright: false, shownavigation: false});
+         *   var gpex4_c1 = gpex4_board.create('curve',[(u)=>4*Math.cos(u)+4,(u)=>2*Math.sin(u)+2,0,2*Math.PI]);
+         *   var gpex4_p2 = gpex4_board.create('glider', [gpex4_c1]);
+         *   gpex4_board.create('button', [1, 7, 'start animation',function(){gpex4_p2.startAnimation(1,8)}]);
+         *   gpex4_board.create('button', [1, 5, 'stop animation',function(){gpex4_p2.stopAnimation()}]);
+         * </script><pre>
          *
          * @example
          * // Divide the slider area into 20 steps and
@@ -1887,13 +1903,58 @@ JXG.extend(
          * @param {Number} [time] Number of milliseconds the animation should last.
          * @param {Object} [options] Optional settings for the animation
          * @param {function} [options.callback] A function that is called as soon as the animation is finished.
-         * @param {String} [options.effect='<>'] animation effects like speed fade in and out. possible values are
-         * '<>' for speed increase on start and slow down at the end (default) and '--' for constant speed during
+         * @param {String} [options.effect='<>'|'>'|'<'] animation effects like speed fade in and out. possible values are
+         * '<>' for speed increase on start and slow down at the end (default), '<' for speed up, '>' for slow down, and '--' for constant speed during
          * the whole animation.
          * @returns {JXG.CoordsElement} Reference to itself.
          * @see JXG.CoordsElement#moveAlong
          * @see JXG.CoordsElement#visit
          * @see JXG.GeometryElement#animate
+         * @example
+         * // moveTo() with different easing options and callback options
+         * let yInit = 3
+         * let [A, B, C, D] = ['==', '<>', '<', '>'].map((s) => board.create('point', [4, yInit--], { name: s, label: { fontSize: 24 } }))
+         * let seg = board.create('segment', [A, [() => A.X(), 0]])  // shows linear
+         *
+         *let isLeftRight = true;
+         *let buttonMove = board.create('button', [-2, 4, 'left',
+         *() => {
+         *    isLeftRight = !isLeftRight;
+         *    buttonMove.rendNodeButton.innerHTML = isLeftRight ? 'left' : 'right'
+         *    let x = isLeftRight ? 4 : -4
+         *    let sym = isLeftRight ? 'triangleleft' : 'triangleright'
+         *
+         *    A.moveTo([x, 3], 1000, { callback: () => A.setAttribute({ face: sym, size: 5 }) })
+         *    B.moveTo([x, 2], 1000, { callback: () => B.setAttribute({ face: sym, size: 5 }), effect: "<>" })
+         *    C.moveTo([x, 1], 1000, { callback: () => C.setAttribute({ face: sym, size: 5 }), effect: "<" })
+         *    D.moveTo([x, 0], 1000, { callback: () => D.setAttribute({ face: sym, size: 5 }), effect: ">" })
+         *
+         *}])
+         *
+          </pre><div id="JXG0f35a50e-e99d-11e8-a1ca-04d3b0c2aad4" class="jxgbox" style="width: 300px; height: 300px;"></div>
+          <script type="text/javascript">
+          {
+*          let board = JXG.JSXGraph.initBoard('JXG0f35a50e-e99d-11e8-a1ca-04d3b0c2aad4')
+          let yInit = 3
+          let [A, B, C, D] = ['==', '<>', '<', '>'].map((s) => board.create('point', [4, yInit--], { name: s, label: { fontSize: 24 } }))
+          let seg = board.create('segment', [A, [() => A.X(), 0]])  // shows linear
+
+         let isLeftRight = true;
+         let buttonMove = board.create('button', [-2, 4, 'left',
+         () => {
+             isLeftRight = !isLeftRight;
+             buttonMove.rendNodeButton.innerHTML = isLeftRight ? 'left' : 'right'
+             let x = isLeftRight ? 4 : -4
+             let sym = isLeftRight ? 'triangleleft' : 'triangleright'
+
+             A.moveTo([x, 3], 1000, { callback: () => A.setAttribute({ face: sym, size: 5 }) })
+             B.moveTo([x, 2], 1000, { callback: () => B.setAttribute({ face: sym, size: 5 }), effect: "<>" })
+             C.moveTo([x, 1], 1000, { callback: () => C.setAttribute({ face: sym, size: 5 }), effect: "<" })
+             D.moveTo([x, 0], 1000, { callback: () => D.setAttribute({ face: sym, size: 5 }), effect: ">" })
+
+         }])
+        }
+        </script><pre>
          */
         moveTo: function (where, time, options) {
             options = options || {};
@@ -1909,10 +1970,24 @@ JXG.extend(
                 dY = where.usrCoords[2] - Y,
                 /** @ignore */
                 stepFun = function (i) {
-                    if (options.effect && options.effect === "<>") {
-                        return Math.pow(Math.sin(((i / steps) * Math.PI) / 2), 2);
+                    let x = i / steps;  // absolute progress of the animatin
+
+                    if (options.effect) {
+                        if (options.effect === "<>") {
+                            return Math.pow(Math.sin((x * Math.PI) / 2), 2);
+                        }
+                        if (options.effect === "<") {   // cubic ease in
+                            return x * x * x;
+                        }
+                        if (options.effect === ">") {   // cubic ease out
+                            return 1 - Math.pow(1 - x, 3);
+                        }
+                        if (options.effect === "==") {
+                            return i / steps;       // linear
+                        }
+                        throw new Error("valid effects are '==', '<>', '>', and '<'.");
                     }
-                    return i / steps;
+                    return i / steps;  // default
                 };
 
             if (
@@ -1956,14 +2031,52 @@ JXG.extend(
          * @param {Number} time Number of milliseconds the animation should last.
          * @param {Object} [options] Optional settings for the animation
          * @param {function} [options.callback] A function that is called as soon as the animation is finished.
-         * @param {String} [options.effect='<>'] animation effects like speed fade in and out. possible values are
-         * '<>' for speed increase on start and slow down at the end (default) and '--' for constant speed during
+         * @param {String} [options.effect='<>'|'>'|'<'] animation effects like speed fade in and out. possible values are
+         * '<>' for speed increase on start and slow down at the end (default), '<' for speed up, '>' for slow down, and '--' for constant speed during
          * the whole animation.
          * @param {Number} [options.repeat=1] How often this animation should be repeated.
          * @returns {JXG.CoordsElement} Reference to itself.
          * @see JXG.CoordsElement#moveAlong
          * @see JXG.CoordsElement#moveTo
          * @see JXG.GeometryElement#animate
+         * @example
+         * // visit() with different easing options
+         * let yInit = 3
+         * let [A, B, C, D] = ['==', '<>', '<', '>'].map((s) => board.create('point', [4, yInit--], { name: s, label: { fontSize: 24 } }))
+         * let seg = board.create('segment', [A, [() => A.X(), 0]])  // shows linear
+         *
+         *let isLeftRight = true;
+         *let buttonVisit = board.create('button', [0, 4, 'visit',
+         *    () => {
+         *        let x = isLeftRight ? 4 : -4
+         *
+         *        A.visit([-x, 3], 4000, { effect: "==", repeat: 2 })  // linear
+         *        B.visit([-x, 2], 4000, { effect: "<>", repeat: 2 })
+         *        C.visit([-x, 1], 4000, { effect: "<", repeat: 2 })
+         *        D.visit([-x, 0], 4000, { effect: ">", repeat: 2 })
+         *    }])
+         *
+          </pre><div id="JXG0f35a50e-e99d-11e8-a1ca-04d3b0c2aad5" class="jxgbox" style="width: 300px; height: 300px;"></div>
+          <script type="text/javascript">
+          {
+*          let board = JXG.JSXGraph.initBoard('JXG0f35a50e-e99d-11e8-a1ca-04d3b0c2aad5')
+          let yInit = 3
+          let [A, B, C, D] = ['==', '<>', '<', '>'].map((s) => board.create('point', [4, yInit--], { name: s, label: { fontSize: 24 } }))
+          let seg = board.create('segment', [A, [() => A.X(), 0]])  // shows linear
+
+         let isLeftRight = true;
+         let buttonVisit = board.create('button', [0, 4, 'visit',
+             () => {
+                 let x = isLeftRight ? 4 : -4
+
+                 A.visit([-x, 3], 4000, { effect: "==", repeat: 2 })  // linear
+                 B.visit([-x, 2], 4000, { effect: "<>", repeat: 2 })
+                 C.visit([-x, 1], 4000, { effect: "<", repeat: 2 })
+                 D.visit([-x, 0], 4000, { effect: ">", repeat: 2 })
+             }])
+            }
+        </script><pre>
+
          */
         visit: function (where, time, options) {
             where = new Coords(Const.COORDS_BY_USER, where, this.board);
@@ -1981,10 +2094,22 @@ JXG.extend(
                 stepFun = function (i) {
                     var x = i < steps / 2 ? (2 * i) / steps : (2 * (steps - i)) / steps;
 
-                    if (options.effect && options.effect === "<>") {
-                        return Math.pow(Math.sin((x * Math.PI) / 2), 2);
-                    }
+                    if (options.effect) {
+                        if (options.effect === "<>") {        // slow at beginning and end
+                            return Math.pow(Math.sin((x * Math.PI) / 2), 2);
+                        }
+                        if (options.effect === "<") {   // cubic ease in
+                            return x * x * x;
+                        }
+                        if (options.effect === ">") {   // cubic ease out
+                            return 1 - Math.pow(1 - x, 3);
+                        }
+                        if (options.effect === "==") {
+                            return x;       // linear
+                        }
+                        throw new Error("valid effects are '==', '<>', '>', and '<'.");
 
+                    }
                     return x;
                 };
 
@@ -2054,16 +2179,12 @@ JXG.extend(
                 ]);
             } else if (this.slideObject.elementClass === Const.OBJECT_CLASS_CURVE) {
                 if (direction > 0) {
-                    newX = Math.round(
-                        (this.intervalCount / stepCount) * this.board.canvasWidth
-                    );
+                    newX = (this.slideObject.maxX() - this.slideObject.minX()) * this.intervalCount / stepCount + this.slideObject.minX();
                 } else {
-                    newX = Math.round(
-                        ((stepCount - this.intervalCount) / stepCount) * this.board.canvasWidth
-                    );
+                    newX = -(this.slideObject.maxX() - this.slideObject.minX()) * this.intervalCount / stepCount + this.slideObject.maxX();
                 }
+                this.coords.setCoordinates(Const.COORDS_BY_USER, [this.slideObject.X(newX), this.slideObject.Y(newX)]);
 
-                this.coords.setCoordinates(Const.COORDS_BY_SCREEN, [newX, 0]);
                 res = Geometry.projectPointToCurve(this, this.slideObject, this.board);
                 this.coords = res[0];
                 this.position = res[1];
