@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -36,13 +36,13 @@
  * @fileoverview In this file the ForeignObject element is defined.
  */
 
-import JXG from "../jxg";
-import Const from "./constants";
-import Coords from "./coords";
-import GeometryElement from "./element";
-import Mat from "../math/math";
-import Type from "../utils/type";
-import CoordsElement from "./coordselement";
+import JXG from "../jxg.js";
+import Const from "./constants.js";
+import Coords from "./coords.js";
+import GeometryElement from "./element.js";
+import Mat from "../math/math.js";
+import Type from "../utils/type.js";
+import CoordsElement from "./coordselement.js";
 
 /**
  * Construct and handle SVG foreignObjects.
@@ -111,7 +111,11 @@ JXG.ForeignObject = function (board, coords, attributes, content, size) {
 
     this.methodMap = JXG.deepCopy(this.methodMap, {
         addTransformation: "addTransform",
-        trans: "addTransform"
+        trans: "addTransform",
+        W: "W",
+        Width: "W",
+        H: "H",
+        Height: "H"
     });
 };
 
@@ -294,9 +298,9 @@ JXG.extend(
          * Set the width and height of the foreignObject. After setting a new size,
          * board.update() or foreignobject.fullUpdate()
          * has to be called to make the change visible.
-         * @param  {number, function, string} width  Number, function or string
+         * @param  {numbe|function|string} width  Number, function or string
          *                            that determines the new width of the foreignObject
-         * @param  {number, function, string} height Number, function or string
+         * @param  {number|function|string} height Number, function or string
          *                            that determines the new height of the foreignObject
          * @returns {JXG.ForeignObject} A reference to the element
          *
@@ -337,7 +341,6 @@ JXG.extend(
  * </p>
  *
  * @pseudo
- * @description
  * @name ForeignObject
  * @augments JXG.ForeignObject
  * @constructor
