@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -39,14 +39,14 @@
  * @version 0.1
  */
 
-import JXG from "../jxg";
-import Mat from "../math/math";
-import Geometry from "../math/geometry";
-import Numerics from "../math/numerics";
-import Const from "./constants";
-import GeometryElement from "./element";
-import Coords from "./coords";
-import Type from "../utils/type";
+import JXG from "../jxg.js";
+import Mat from "../math/math.js";
+import Geometry from "../math/geometry.js";
+import Numerics from "../math/numerics.js";
+import Const from "./constants.js";
+import GeometryElement from "./element.js";
+import Coords from "./coords.js";
+import Type from "../utils/type.js";
 
 /**
  * Creates ticks for an axis.
@@ -215,11 +215,8 @@ JXG.extend(
          * @returns {Boolean} True if (x,y) is near the line, False otherwise.
          */
         hasPoint: function (x, y) {
-            var i,
-                t,
-                len = (this.ticks && this.ticks.length) || 0,
-                r,
-                type;
+            var i, t, r, type,
+                len = (this.ticks && this.ticks.length) || 0;
 
             if (Type.isObject(Type.evaluate(this.visProp.precision))) {
                 type = this.board._inputDevice;
@@ -269,17 +266,15 @@ JXG.extend(
                             if (this.line.stdform[1] === 0) {
                                 // Allow dragging near axes only.
                                 if (
-                                    Math.abs(y - (t[1][0] + t[1][1]) * 0.5) < 2 * r &&
-                                    t[0][0] - r < x &&
-                                    x < t[0][1] + r
+                                    Math.abs(y - this.line.point1.coords.scrCoords[2]) < 2 * r &&
+                                    t[0][0] - r < x && x < t[0][1] + r
                                 ) {
                                     return true;
                                 }
                             } else if (this.line.stdform[2] === 0) {
                                 if (
-                                    Math.abs(x - (t[0][0] + t[0][1]) * 0.5) < 2 * r &&
-                                    t[1][0] - r < y &&
-                                    y < t[1][1] + r
+                                    Math.abs(x - this.line.point1.coords.scrCoords[1]) < 2 * r &&
+                                    t[1][0] - r < y && y < t[1][1] + r
                                 ) {
                                     return true;
                                 }
@@ -300,8 +295,7 @@ JXG.extend(
          * @returns {JXG.Ticks} this element
          */
         setPositionDirectly: function (method, coords, oldcoords) {
-            var dx,
-                dy,
+            var dx, dy,
                 c = new Coords(method, coords, this.board),
                 oldc = new Coords(method, oldcoords, this.board),
                 bb = this.board.getBoundingBox();
@@ -374,8 +368,8 @@ JXG.extend(
             if (Type.evaluate(this.visProp.type) === "polar") {
                 bb = this.board.getBoundingBox();
                 r_max = Math.max(
-                    Math.sqrt(bb[0] * bb[0] + bb[1] * bb[1]),
-                    Math.sqrt(bb[2] * bb[2] + bb[3] * bb[3])
+                    Mat.hypot(bb[0], bb[1]),
+                    Mat.hypot(bb[2], bb[3])
                 );
                 b.upper = r_max;
             }
@@ -443,10 +437,7 @@ JXG.extend(
             this.dy = this.dyMaj;
 
             // After this, the length of the vector (dxMaj, dyMaj) in screen coordinates is equal to distMaj pixel.
-            d = Math.sqrt(
-                this.dxMaj * this.dxMaj * this.board.unitX * this.board.unitX +
-                this.dyMaj * this.dyMaj * this.board.unitY * this.board.unitY
-            );
+            d = Mat.hypot(this.dxMaj * this.board.unitX, this.dyMaj * this.board.unitY);
             this.dxMaj *= (distMaj / d) * this.board.unitX;
             this.dyMaj *= (distMaj / d) * this.board.unitY;
             this.dxMin *= (distMin / d) * this.board.unitX;
@@ -555,6 +546,7 @@ JXG.extend(
                 // We use the distance from zero to P1 and P2 to establish lower and higher points
                 dZeroPoint1, dZeroPoint2,
                 arrowData,
+                // angle,
                 a1, a2, m1, m2,
                 eps = Mat.eps * 10,
                 ev_sf = Type.evaluate(this.line.visProp.straightfirst),
@@ -595,7 +587,7 @@ JXG.extend(
                 m2 = this.getDistanceFromZero(coordsZero, point2);
                 Geometry.calcStraight(this.line, point1, point2, Type.evaluate(this.line.visProp.margin));
                 m1 = this.getDistanceFromZero(coordsZero, point1) - m1;
-                m2 = this.getDistanceFromZero(coordsZero, point2) . m2;
+                m2 = this.getDistanceFromZero(coordsZero, point2).m2;
             } else {
                 // This function projects the corners of the board to the line.
                 // This is important for diagonal lines with infinite tick lines.
@@ -649,6 +641,7 @@ JXG.extend(
                 }
             } else if (dZeroPoint2 < dZeroPoint1) {
                 // Line goes P2->P1
+                // Does this happen at all?
                 lowerBound = dZeroPoint2;
                 upperBound = dZeroPoint1;
 
@@ -675,7 +668,7 @@ JXG.extend(
         },
 
         /**
-         * Calculates the distance in user coordinates from zero to a given point including its sign.
+         * Calculates the signed distance in user coordinates from zero to a given point.
          * Sign is positive, if the direction from zero to point is the same as the direction
          * zero to point2 of the line.
          *
@@ -722,9 +715,9 @@ JXG.extend(
             var tickPosition,
                 eps = Mat.eps,
                 deltas, ticksDelta,
-                ev_mia = Type.evaluate(this.visProp.minorticksinarrow),
-                ev_maa = Type.evaluate(this.visProp.minorticksinarrow),
-                ev_mla = Type.evaluate(this.visProp.minorticksinarrow),
+                // ev_mia = Type.evaluate(this.visProp.minorticksinarrow),
+                // ev_maa = Type.evaluate(this.visProp.minorticksinarrow),
+                // ev_mla = Type.evaluate(this.visProp.minorticksinarrow),
                 ev_mt = Type.evaluate(this.visProp.minorticks);
 
             // Determine a proposed distance between major ticks in user units
@@ -825,7 +818,7 @@ JXG.extend(
                 d = this.getXandYdeltas();
                 d.x *= this.board.unitX;
                 d.y *= this.board.unitY;
-                minDist /= Math.sqrt(d.x * d.x + d.y * d.y);
+                minDist /= Mat.hypot(d.x, d.y);
                 minDist *= (ev_minti + 1);
 
                 // Determine minimal delta to fulfill the minTicksDistance constraint
@@ -1068,25 +1061,25 @@ JXG.extend(
                 point2UsrCoords,
                 distP1P2 = this.line.point1.Dist(this.line.point2);
 
-            if (this.line.type === Const.OBJECT_TYPE_AXIS) {
-                // When line is an Axis, direction depends on board coordinates system
-                // Assume line.point1 and line.point2 are in correct order
-                point1UsrCoords = this.line.point1.coords.usrCoords;
-                point2UsrCoords = this.line.point2.coords.usrCoords;
-                // Check if direction is incorrect, then swap
-                if (
-                    point1UsrCoords[1] > point2UsrCoords[1] ||
-                    (Math.abs(point1UsrCoords[1] - point2UsrCoords[1]) < Mat.eps &&
-                        point1UsrCoords[2] > point2UsrCoords[2])
-                ) {
-                    point1UsrCoords = this.line.point2.coords.usrCoords;
-                    point2UsrCoords = this.line.point1.coords.usrCoords;
-                }
-            } /* if (this.line.elementClass === Const.OBJECT_CLASS_LINE)*/ else {
+            // if (this.line.type === Const.OBJECT_TYPE_AXIS) {
+            //     // When line is an Axis, direction depends on board coordinates system
+            //     // Assume line.point1 and line.point2 are in correct order
+            //     point1UsrCoords = this.line.point1.coords.usrCoords;
+            //     point2UsrCoords = this.line.point2.coords.usrCoords;
+            //     // Check if direction is incorrect, then swap
+            //     if (
+            //         point1UsrCoords[1] > point2UsrCoords[1] ||
+            //         (Math.abs(point1UsrCoords[1] - point2UsrCoords[1]) < Mat.eps &&
+            //             point1UsrCoords[2] > point2UsrCoords[2])
+            //     ) {
+            //         point1UsrCoords = this.line.point2.coords.usrCoords;
+            //         point2UsrCoords = this.line.point1.coords.usrCoords;
+            //     }
+            // } /* if (this.line.elementClass === Const.OBJECT_CLASS_LINE)*/ else {
                 // Line direction is always from P1 to P2 for non axis types
                 point1UsrCoords = this.line.point1.coords.usrCoords;
                 point2UsrCoords = this.line.point2.coords.usrCoords;
-            }
+            // }
             return {
                 x: (point2UsrCoords[1] - point1UsrCoords[1]) / distP1P2,
                 y: (point2UsrCoords[2] - point1UsrCoords[2]) / distP1P2
@@ -1166,10 +1159,10 @@ JXG.extend(
 
                 // usrCoords: Test if 'circle' is inside of the canvas
                 c = coords.usrCoords;
-                r = Math.sqrt(c[1] * c[1] + c[2] * c[2]);
+                r = Mat.hypot(c[1], c[2]);
                 r_max = Math.max(
-                    Math.sqrt(bb[0] * bb[0] + bb[1] * bb[1]),
-                    Math.sqrt(bb[2] * bb[2] + bb[3] * bb[3])
+                    Mat.hypot(bb[0], bb[1]),
+                    Mat.hypot(bb[2], bb[3])
                 );
 
                 if (r < r_max) {
@@ -1215,7 +1208,7 @@ JXG.extend(
                             Mat.innerProduct(
                                 intersection[1].usrCoords.slice(1, 3),
                                 this.line.stdform.slice(1, 3)
-                            ) + this.line.stdform[0],
+                            ) + this.line.stdform[0]
                         ];
 
                         // Reverse intersection array order if first intersection is not the leftmost one.
@@ -1297,27 +1290,36 @@ JXG.extend(
         formatLabelText: function (value) {
             var labelText,
                 digits,
+                ev_um = Type.evaluate(this.visProp.label.usemathjax),
+                ev_uk = Type.evaluate(this.visProp.label.usekatex),
                 ev_s = Type.evaluate(this.visProp.scalesymbol);
 
             if (Type.isNumber(value)) {
-                digits = Type.evaluate(this.visProp.digits);
-
-                if (this.useLocale()) {
-                    labelText = this.formatNumberLocale(value, digits);
+                if (Type.evaluate(this.visProp.label.tofraction)) {
+                    if (ev_um) {
+                        labelText = '\\(' + Type.toFraction(value, true) + '\\)';
+                    } else {
+                        labelText = Type.toFraction(value, ev_uk);
+                    }
                 } else {
-                    labelText = (Math.round(value * 1e11) / 1e11).toString();
+                    digits = Type.evaluate(this.visProp.digits);
+                    if (this.useLocale()) {
+                        labelText = this.formatNumberLocale(value, digits);
+                    } else {
+                        labelText = (Math.round(value * 1e11) / 1e11).toString();
 
-                    if (
-                        labelText.length > Type.evaluate(this.visProp.maxlabellength) ||
-                        labelText.indexOf("e") !== -1
-                    ) {
-                        if (Type.evaluate(this.visProp.precision) !== 3 && digits === 3) {
-                            // Use the deprecated attribute "precision"
-                            digits = Type.evaluate(this.visProp.precision);
+                        if (
+                            labelText.length > Type.evaluate(this.visProp.maxlabellength) ||
+                            labelText.indexOf("e") !== -1
+                        ) {
+                            if (Type.evaluate(this.visProp.precision) !== 3 && digits === 3) {
+                                // Use the deprecated attribute "precision"
+                                digits = Type.evaluate(this.visProp.precision);
+                            }
+
+                            //labelText = value.toPrecision(digits).toString();
+                            labelText = value.toExponential(digits).toString();
                         }
-
-                        //labelText = value.toPrecision(digits).toString();
-                        labelText = value.toExponential(digits).toString();
                     }
                 }
 
@@ -1576,7 +1578,7 @@ JXG.extend(
             for (j = lenData; j < lenLabels; j++) {
                 this.board.renderer.display(this.labels[j], false);
                 // Tick labels have the attribute "visible: 'inherit'"
-                // This must explicitely set to false, otherwise
+                // This must explicitly set to false, otherwise
                 // this labels would be set to visible in the upcoming
                 // update of the labels.
                 this.labels[j].visProp.visible = this.labels[j].visPropCalc.visible = false;
@@ -1653,7 +1655,6 @@ JXG.extend(
  * The default value is "left".
  *
  * @pseudo
- * @description
  * @name Ticks
  * @augments JXG.Ticks
  * @constructor
@@ -1687,6 +1688,43 @@ JXG.extend(
  *   var t = board.create('ticks', [l1, 2], {ticksDistance: 2, majorHeight: 40});
  * })();
  * </script><pre>
+ * @example
+ *  // Create ticks labels as fractions
+ * board.create('axis', [[0,1], [1,1]], {
+ *     ticks: {
+ *         label: {
+ *             toFraction: true,
+ *             useMathjax: true,
+ *             display: 'html',
+ *             anchorX: 'middle',
+ *             offset: [0, -10]
+ *         }
+ *     }
+ * });
+ *
+ * </pre><div id="JXG4455acb2-6bf3-4801-8887-d7fcc1e4e1da" class="jxgbox" style="width: 300px; height: 300px;"></div>
+ * <script src="https://cdn.jsdelivr.net/npm/mathjax@3/es5/tex-chtml.js" id="MathJax-script"></script>
+ * <script type="text/javascript">
+ *     (function() {
+ *         var board = JXG.JSXGraph.initBoard('JXG4455acb2-6bf3-4801-8887-d7fcc1e4e1da',
+ *             {boundingbox: [-1.2, 2.3, 1.2, -2.3], axis: true, showcopyright: false, shownavigation: false});
+ *             board.create('axis', [[0,1], [1,1]], {
+ *                 ticks: {
+ *                     label: {
+ *                         toFraction: true,
+ *             useMathjax: true,
+ *             display: 'html',
+ *             anchorX: 'middle',
+ *             offset: [0, -10]
+ *                     }
+ *                 }
+ *             });
+ *
+ *     })();
+ *
+ * </script><pre>
+ *
+ * @example
  */
 JXG.createTicks = function (board, parents, attributes) {
     var el,
@@ -1728,7 +1766,6 @@ JXG.createTicks = function (board, parents, attributes) {
 /**
  * @class Hatches can be used to mark congruent lines or curves.
  * @pseudo
- * @description
  * @name Hatch
  * @augments JXG.Ticks
  * @constructor
