@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -38,10 +38,11 @@
  * @author A.W.
  */
 
-import JXG from "../jxg";
-import Const from "./constants";
-import GeometryElement from "./element";
-import Type from "../utils/type";
+import JXG from "../jxg.js";
+import Const from "./constants.js";
+import Mat from "../math/math.js";
+import GeometryElement from "./element.js";
+import Type from "../utils/type.js";
 
 /**
  * Constructs a new Turtle object.
@@ -173,8 +174,10 @@ JXG.Turtle = function (board, parents, attributes) {
             lt: 'left',
             penUp: 'penUp',
             pu: 'penUp',
+            up: 'penUp',
             penDown: 'penDown',
             pd: 'penDown',
+            down: 'penDown',
             clearScreen: 'clearScreen',
             cs: 'clearScreen',
             clean: 'clean',
@@ -182,19 +185,29 @@ JXG.Turtle = function (board, parents, attributes) {
             home: 'home',
             hideTurtle: 'hideTurtle',
             ht: 'hideTurtle',
+            hide: 'hideTurtle',
             showTurtle: 'showTurtle',
             st: 'showTurtle',
+            show: 'showTurtle',
             penSize: 'setPenSize',
+            setPenSize: 'setPenSize',
             penColor: 'setPenColor',
+            setPenColor: 'setPenColor',
+            highlightPenColor: 'setHighlightPenColor',
+            setHighlightPenColor: 'setHighlightPenColor',
             getPenColor: 'getPenColor',
+            Color: 'getPenColor',
             getHighlightPenColor: 'getHighlightPenColor',
+            HighlightColor: 'getHighlightPenColor',
             getPenSize: 'getPenSize',
+            Size: 'getPenSize',
             pushTurtle: 'pushTurtle',
             push: 'pushTurtle',
             popTurtle: 'popTurtle',
             pop: 'popTurtle',
             lookTo: 'lookTo',
             pos: 'pos',
+            Pos: 'pos',
             moveTo: 'moveTo',
             X: 'X',
             Y: 'Y'
@@ -221,10 +234,7 @@ JXG.extend(
             };
 
             this.arrowLen =
-                20 /
-                Math.sqrt(
-                    this.board.unitX * this.board.unitX + this.board.unitY * this.board.unitY
-                );
+                20 / Mat.hypot(this.board.unitX, this.board.unitY);
 
             this.pos = [x, y];
             this.isPenDown = true;
@@ -494,8 +504,8 @@ JXG.extend(
 
         /**
          * Get attribute of the last turtle curve object.
-         * 
-         * @param {String} key 
+         *
+         * @param {String} key
          * @returns attribute value
          * @private
          */
