@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -37,13 +37,13 @@
  * style and functional properties that are required to draw an arc on a board.
  */
 
-import JXG from "../jxg";
-import Geometry from "../math/geometry";
-import Mat from "../math/math";
-import Coords from "../base/coords";
-import Circle from "../base/circle";
-import Type from "../utils/type";
-import Const from "../base/constants";
+import JXG from "../jxg.js";
+import Geometry from "../math/geometry.js";
+import Mat from "../math/math.js";
+import Coords from "../base/coords.js";
+import Circle from "../base/circle.js";
+import Type from "../utils/type.js";
+import Const from "../base/constants.js";
 
 /**
  * @class An arc is a segment of the circumference of a circle. It is defined by a center, one point that
@@ -100,10 +100,11 @@ import Const from "../base/constants";
 JXG.createArc = function (board, parents, attributes) {
     var el, attr, points;
 
+    // attributes.radiusPoint = {visible: false};
     points = Type.providePoints(board, parents, attributes, "arc", [
         "center",
-        "radiusPoint",
-        "anglePoint"
+        "radiuspoint",
+        "anglepoint"
     ]);
     if (points === false || points.length < 3) {
         throw new Error(
@@ -181,6 +182,10 @@ JXG.createArc = function (board, parents, attributes) {
     el.useDirection = attr.usedirection;
 
     // documented in JXG.Curve
+    /**
+     * @class
+     * @ignore
+     */
     el.updateDataArray = function () {
         var ar,
             phi,
@@ -255,14 +260,53 @@ JXG.createArc = function (board, parents, attributes) {
     };
 
     /**
-     * Returns the length of the arc.
+     * Returns the length of the arc or the value of the angle spanned by the arc.
      * @memberOf Arc.prototype
      * @name Value
      * @function
-     * @returns {Number} The arc length
+     * @param {String} [unit='length'] Unit of the returned values. Possible units are
+     * <ul>
+     * <li> 'length' (default): length of the arc line
+     * <li> 'radians': angle spanned by the arc in radians
+     * <li> 'degrees': angle spanned by the arc in degrees
+     * <li> 'semicircle': angle spanned by the arc in radians as a multiple of &pi;, e.g. if the angle is 1.5&pi;, 1.5 will be returned.
+     * <li> 'circle': angle spanned by the arc in radians as a multiple of 2&pi;
+     * </ul>
+     * It is sufficient to supply the first three characters of the unit, e.g. 'len'.
+     * @param {Number} [rad=undefined] Value of angle which can be used instead of the generic one.
+     * @returns {Number} The arc length or the angle value in various units.
      */
-    el.Value = function () {
-        return this.Radius() * Geometry.rad(this.radiuspoint, this.center, this.anglepoint);
+    el.Value = function (unit, rad) {
+        var val;
+
+        rad = rad || Geometry.rad(this.radiuspoint, this.center, this.anglepoint);
+
+        unit = unit || 'length';
+        unit = unit.toLocaleLowerCase();
+        if (unit === '' || unit.indexOf('len') === 0) {
+            val = rad * this.Radius();
+        } else if (unit.indexOf('rad') === 0) {
+            val = rad;
+        } else if (unit.indexOf('deg') === 0) {
+            val = rad * 180 / Math.PI;
+        } else if (unit.indexOf('sem') === 0) {
+            val = rad / Math.PI;
+        } else if (unit.indexOf('cir') === 0) {
+            val = rad * 0.5 / Math.PI;
+        }
+
+        return val;
+    };
+
+    /**
+     * Arc length.
+     * @memberOf Arc.prototype
+     * @name L
+     * @returns {Number} Length of the arc.
+     * @see Arc#Value
+     */
+    el.L = function() {
+        return this.Value('length');
     };
 
     // documented in geometry element
@@ -339,6 +383,10 @@ JXG.createArc = function (board, parents, attributes) {
     };
 
     // documented in geometry element
+    /**
+     * @class
+     * @ignore
+     */
     el.getLabelAnchor = function () {
         var coords,
             vec,
@@ -376,7 +424,7 @@ JXG.createArc = function (board, parents, attributes) {
         vecx = coords.usrCoords[1] - pmc[1];
         vecy = coords.usrCoords[2] - pmc[2];
 
-        len = Math.sqrt(vecx * vecx + vecy * vecy);
+        len = Mat.hypot(vecx, vecy);
         vecx = (vecx * (len + dx)) / len;
         vecy = (vecy * (len + dy)) / len;
         vec = [pmc[1] + vecx, pmc[2] + vecy];
@@ -395,10 +443,12 @@ JXG.createArc = function (board, parents, attributes) {
     el.methodMap = JXG.deepCopy(el.methodMap, {
         getRadius: "getRadius",
         radius: "Radius",
+        Radius: "Radius",
         center: "center",
         radiuspoint: "radiuspoint",
         anglepoint: "anglepoint",
-        Value: "Value"
+        Value: "Value",
+        L: "L"
     });
 
     el.prepareUpdate().update();
@@ -628,11 +678,3 @@ JXG.createMajorArc = function (board, parents, attributes) {
 };
 
 JXG.registerElement("majorarc", JXG.createMajorArc);
-
-// export default {
-//     createArc: JXG.createArc,
-//     createSemicircle: JXG.createSemicircle,
-//     createCircumcircleArc: JXG.createCircumcircleArc,
-//     createMinorArc: JXG.createMinorArc,
-//     createMajorArc: JXG.createMajorArc
-// };
