@@ -1,5 +1,5 @@
 /*
-    Copyright 2018-2023
+    Copyright 2018-2024
         Alfred Wassermann,
         Tigran Saluev
 
@@ -32,8 +32,8 @@
  * @fileoverview In this file the Comb element is defined.
  */
 
-import JXG from "../jxg";
-import Type from "../utils/type";
+import JXG from "../jxg.js";
+import Type from "../utils/type.js";
 
 /**
  * @class A comb to display domains of inequalities.
@@ -188,9 +188,10 @@ JXG.createComb = function (board, parents, attributes) {
 
     attr = Type.copyAttributes(attributes, board.options, 'comb');
     // Type.merge(attr, Type.copyAttributes(attributes, board.options, 'comb', 'curve'));
-    c = board.create('curve', [[0], [0]], attr);
+     c = board.create('curve', [[0], [0]], attr);
 
     /**
+     * @class
      * @ignore
      */
     c.updateDataArray = function () {
