@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -36,19 +36,18 @@
  * @fileoverview In this file the conic sections defined.
  */
 
-import JXG from "../jxg";
-import Const from "../base/constants";
-import Coords from "../base/coords";
-import Mat from "../math/math";
-import Numerics from "../math/numerics";
-import Geometry from "../math/geometry";
-import Type from "../utils/type";
+import JXG from "../jxg.js";
+import Const from "../base/constants.js";
+import Coords from "../base/coords.js";
+import Mat from "../math/math.js";
+import Numerics from "../math/numerics.js";
+import Geometry from "../math/geometry.js";
+import Type from "../utils/type.js";
 
 /**
  * @class This element is used to provide a constructor for an ellipse. An ellipse is given by two points (the foci) and a third point on the ellipse or
  * the length of the major axis.
  * @pseudo
- * @description
  * @name Ellipse
  * @augments Conic
  * @constructor
@@ -207,6 +206,10 @@ JXG.createEllipse = function (board, parents, attributes) {
         attr_center
     );
 
+    /**
+     * @class
+     * @ignore
+     */
     curve = board.create(
         "curve",
         [
@@ -291,6 +294,7 @@ JXG.createEllipse = function (board, parents, attributes) {
      * @param {Number} y Coordinate in y direction, screen coordinates.
      * @returns {Boolean} True if (x,y) is near the ellipse, False otherwise.
      * @private
+     * @ignore
      */
     curve.hasPoint = function (x, y) {
         var ac, bc, r, p, dist;
@@ -326,7 +330,6 @@ JXG.createEllipse = function (board, parents, attributes) {
  * @class This element is used to provide a constructor for an hyperbola. An hyperbola is given by two points (the foci) and a third point on the hyperbola or
  * the length of the major axis.
  * @pseudo
- * @description
  * @name Hyperbola
  * @augments Conic
  * @constructor
@@ -453,6 +456,10 @@ JXG.createHyperbola = function (board, parents, attributes) {
         attr_center
     );
 
+    /**
+     * @class
+     * @ignore
+     */
     curve = board.create(
         "curve",
         [
@@ -545,11 +552,11 @@ JXG.createHyperbola = function (board, parents, attributes) {
 /**
  * @class This element is used to provide a constructor for a parabola. A parabola is given by one point (the focus) and a line (the directrix).
  * @pseudo
- * @description
  * @name Parabola
  * @augments Conic
  * @constructor
- * @type JXG.Curve
+ * @type Object
+ * @description JXG.Curve
  * @throws {Exception} If the element cannot be constructed with the given parent objects an exception is thrown.
  * @param {JXG.Point,array_JXG.Line} point,line Parent elements are a point and a line or a pair of coordinates.
  * Optional parameters three and four are numbers which define the curve length (e.g. start/end). Default values are -pi and pi.
@@ -654,7 +661,10 @@ JXG.createParabola = function (board, parents, attributes) {
         attr_center
     );
 
-    /** @ignore */
+    /**
+     * @class
+     * @ignore
+     */
     curve = board.create(
         "curve",
         [
@@ -768,7 +778,6 @@ JXG.createParabola = function (board, parents, attributes) {
  *     board.create('conic', [A, C, F, B/2, D/2, E/2]);
  * </pre>
  * @pseudo
- * @description
  * @name Conic
  * @augments JXG.Curve
  * @constructor
@@ -999,6 +1008,10 @@ JXG.createConic = function (board, parents, attributes) {
 
     // Here, the defining functions for the curve are just dummy functions.
     // In polarForm there is a reference to curve.quadraticform.
+    /**
+     * @class
+     * @ignore
+     */
     curve = board.create(
         "curve",
         [
@@ -1016,7 +1029,7 @@ JXG.createConic = function (board, parents, attributes) {
 
     /** @ignore */
     polarForm = function (phi, suspendUpdate) {
-        var i, j, len, v;
+        var i, j, v; // len,;
 
         if (!suspendUpdate) {
             if (givenByPoints) {
@@ -1054,16 +1067,16 @@ JXG.createConic = function (board, parents, attributes) {
             }
 
             // Normalize the Eigenvectors
-            for (i = 0; i < 3; i++) {
-                len = 0.0;
-                for (j = 0; j < 3; j++) {
-                    len += eigen[1][j][i] * eigen[1][j][i];
-                }
-                len = Math.sqrt(len);
-                /*for (j = 0; j < 3; j++) {
-                        //eigen[1][j][i] /= len;
-                    }*/
-            }
+            // for (i = 0; i < 3; i++) {
+            //     // len = Mat.hypot(eigen[1][0][i], eigen[1][1][i], eigen[1][2][i])
+            //     for (j = 0; j < 3; j++) {
+            //         len += eigen[1][j][i] * eigen[1][j][i];
+            //     }
+            //     len = Math.sqrt(len);
+            //     /*for (j = 0; j < 3; j++) {
+            //             //eigen[1][j][i] /= len;
+            //         }*/
+            // }
             rotationMatrix = eigen[1];
             c = Math.sqrt(Math.abs(eigen[0][0][0]));
             a = Math.sqrt(Math.abs(eigen[0][1][1]));
