@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -36,14 +36,20 @@
  * @fileoverview In this file the Text element is defined.
  */
 
-import JXG from "../jxg";
-import Env from "../utils/env";
-import Type from "../utils/type";
+import JXG from "../jxg.js";
+import Env from "../utils/env.js";
+import Type from "../utils/type.js";
 
 /**
+ * @class
  * @ignore
  */
 var priv = {
+     /**
+     * @class
+     * @ignore
+     */
+
     InputInputEventHandler: function (evt) {
         this._value = this.rendNodeInput.value;
         this.board.update();
@@ -53,17 +59,19 @@ var priv = {
 /**
  * @class This element is used to provide a constructor for special texts containing a
  * HTML form input element.
- * <p>
- * If the width of element is set with the attribute "cssStyle", the width of the
- * label must be added.
- * <p>
  * For this element, the attribute "display" has to have the value 'html' (which is the default).
- * <p>
- * The underlying HTML input field can be accessed through the sub-object 'rendNodeInput', e.g. to
+ * If the width of element is set with the attribute "cssStyle", the width of the
+ * label must be added because cssStyle affects the surrounding div element.
+ *
+ * <p><b>Setting a CSS class:</b> The attribute <tt>cssClass</tt> affects the HTML div element that contains the input element. To change the CSS properties of the HTML input element a selector of the form
+ * <tt>.myinput > input { ... }</tt> has to be used. See the analog example for buttons:
+ * {@link Button}.
+ *
+ * <p><b>Access the input element with JavaScript:</b>
+ * The underlying HTML button element can be accessed through the sub-object 'rendNodeInput', e.g. to
  * add event listeners.
- * 
+ *
  * @pseudo
- * @description
  * @name Input
  * @augments Text
  * @constructor
@@ -124,19 +132,19 @@ var priv = {
  *      t1_board.update();
  *  }
  * </script><pre>
- * 
+ *
  * @example
  * // Add the `keyup` event to an input field
  * var A = board.create('point', [3, -2]);
  * var i = board.create('input', [-4, -4, "1", "x "]);
- * 
+ *
  * i.rendNodeInput.addEventListener("keyup", ( function () {
  *    var x = parseFloat(this.value);
  *    if (!isNaN(x)) {
  * 	   A.moveTo([x, 3], 100);
  *    }
  * }));
- * 
+ *
  * </pre><div id="JXG81c84fa7-3f36-4874-9e0f-d4b9e93e755b" class="jxgbox" style="width: 300px; height: 300px;"></div>
  * <script type="text/javascript">
  *     (function() {
@@ -144,28 +152,28 @@ var priv = {
  *             {boundingbox: [-5, 5, 5, -5], axis: true, showcopyright: false, shownavigation: false});
  *     var A = board.create('point', [3, -2]);
  *     var i = board.create('input', [-4, -4, "1", "x "]);
- *     
+ *
  *     i.rendNodeInput.addEventListener("keyup", ( function () {
  *        var x = parseFloat(this.value);
  *        if (!isNaN(x)) {
  *     	    A.moveTo([x, 3], 100);
  *        }
  *     }));
- * 
+ *
  *     })();
- * 
+ *
  * </script><pre>
- * 
+ *
  * @example
  * // Add the `change` event to an input field
  * var A = board.create('point', [3, -2]);
  * var i = board.create('input', [-4, -4, "1", "x "]);
- * 
+ *
  * i.rendNodeInput.addEventListener("change", ( function () {
  *    var x = parseFloat(i.Value());
  *    A.moveTo([x, 2], 100);
  * }));
- * 
+ *
  * </pre><div id="JXG51c4d78b-a7ad-4c34-a983-b3ddae6192d7" class="jxgbox" style="width: 300px; height: 300px;"></div>
  * <script type="text/javascript">
  *     (function() {
@@ -173,29 +181,29 @@ var priv = {
  *             {boundingbox: [-8, 8, 8,-8], axis: true, showcopyright: false, shownavigation: false});
  *     var A = board.create('point', [3, -2]);
  *     var i = board.create('input', [-4, -4, "1", "x "]);
- *     
+ *
  *     i.rendNodeInput.addEventListener("change", ( function () {
  *        var x = parseFloat(i.Value());
  *        A.moveTo([x, 2], 100);
  *     }));
- * 
+ *
  *     })();
- * 
+ *
  * </script><pre>
- * 
- * 
+ *
+ *
  * @example
  *   Apply CSS classes to label and input tag
  *     &lt;style&gt;
  *         div.JXGtext_inp {
  *             font-weight: bold;
  *         }
- * 
+ *
  *         // Label
  *         div.JXGtext_inp > span > span {
  *             padding: 3px;
  *         }
- * 
+ *
  *         // Input field
  *         div.JXGtext_inp > span > input {
  *             width: 100px;
@@ -203,21 +211,21 @@ var priv = {
  *             border-radius: 25px;
  *         }
  *     &lt;/style&gt;
- * 
+ *
  * var inp = board.create('input', [-6, 1, 'x', 'y'], {
  *      CssClass: 'JXGtext_inp', HighlightCssClass: 'JXGtext_inp'
  * });
- * 
+ *
  * </pre>
  *         <style>
  *             div.JXGtext_inp {
  *                 font-weight: bold;
  *             }
- *     
+ *
  *             div.JXGtext_inp > span > span {
  *                 padding: 3px;
  *             }
- *     
+ *
  *             div.JXGtext_inp > span > input {
  *                 width: 100px;
  *                 border: solid 4px red;
@@ -230,10 +238,10 @@ var priv = {
  *         var board = JXG.JSXGraph.initBoard('JXGa3642ebd-a7dc-41ac-beb2-0c9e705ab8b4',
  *             {boundingbox: [-8, 8, 8,-8], axis: true, showcopyright: false, shownavigation: false});
  *         var inp = board.create('input', [-6, 1, 'x', 'y'], {CssClass: 'JXGtext_inp', HighlightCssClass: 'JXGtext_inp'});
- * 
+ *
  *     })();
  * </script><pre>
- * 
+ *
  */
 JXG.createInput = function (board, parents, attributes) {
     var t,
@@ -268,6 +276,11 @@ JXG.createInput = function (board, parents, attributes) {
     t.setText(parents[3]);
 
     t._value = parents[2];
+
+     /**
+     * @class
+     * @ignore
+     */
     t.update = function () {
         if (this.needsUpdate) {
             JXG.Text.prototype.update.call(this);
@@ -327,6 +340,12 @@ JXG.createInput = function (board, parents, attributes) {
      * </script><pre>
      *
      */
+
+     /**
+     * @class
+     * @ignore
+     */
+
     t.set = function (val) {
         this._value = val;
         this.rendNodeInput.value = val;
