@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -36,10 +36,10 @@
  * @fileoverview Example file for a triangle implemented as a extension to JSXGraph.
  */
 
-import JXG from "../jxg";
-import Type from "../utils/type";
-import Const from "../base/constants";
-import Polygon from "../base/polygon";
+import JXG from "../jxg.js";
+import Type from "../utils/type.js";
+import Const from "../base/constants.js";
+import Polygon from "../base/polygon.js";
 
 var priv = {
     removeSlopeTriangle: function () {
@@ -59,6 +59,9 @@ var priv = {
     },
     Value: function () {
         return this.tangent.getSlope();
+    },
+    Direction: function() {
+        return this.tangent.Direction();
     }
 };
 
@@ -177,7 +180,7 @@ JXG.createSlopeTriangle = function (board, parents, attributes) {
     );
 
     attr = Type.copyAttributes(attributes, board.options, "slopetriangle");
-    attr.borders = Type.copyAttributes(attr.borders, board.options, "slopetriangle", "borders");
+    // attr.borders = Type.copyAttributes(attr.borders, board.options, "slopetriangle", "borders");
     el = board.create("polygon", [tglide, glider, toppoint], attr);
 
     /**
@@ -188,6 +191,16 @@ JXG.createSlopeTriangle = function (board, parents, attributes) {
      * @returns {Number} slope of the tangent.
      */
     el.Value = priv.Value;
+
+    /**
+     * Returns the direction of the slope triangle, that is the direction of the tangent.
+     * @name Direction
+     * @memberOf Slopetriangle.prototype
+     * @see Line#Direction
+     * @function
+     * @returns {Number} slope of the tangent.
+     */
+    el.Direction = priv.Direction;
     el.tangent = tangent;
     el._isPrivateTangent = isPrivateTangent;
 
@@ -196,21 +209,33 @@ JXG.createSlopeTriangle = function (board, parents, attributes) {
     el.borders[2].setArrow(false, false);
 
     attr = Type.copyAttributes(attributes, board.options, "slopetriangle", "label");
-    label = board.create(
-        "text",
-        [
-            function () {
-                return glider.X() + 0.1;
-            },
-            function () {
-                return (glider.Y() + toppoint.Y()) * 0.5;
-            },
-            function () {
-                return "";
-            }
-        ],
-        attr
-    );
+    //label = board.create("text", [
+    //         function () {
+    //             return glider.X() + 0.1;
+    //         },
+    //         function () {
+    //             return (glider.Y() + toppoint.Y()) * 0.5;
+    //         },
+    //         function () {
+    //             return "";
+    //         }
+    //     ],
+    //     attr
+    // );
+
+    attr = Type.copyAttributes(attr, board.options, "label");
+    // Add label to vertical polygon edge
+    attr.isLabel = true;
+    attr.anchor = el.borders[1];
+    attr.priv = el.borders[1].visProp.priv;
+    attr.id = el.borders[1].id + "Label";
+
+    label = board.create("text", [0, 0, function () { return ""; }], attr);
+    label.needsUpdate = true;
+    label.dump = false;
+    el.borders[1].label = label;
+    el.borders[1].hasLabel = true;
+    el.borders[1].visProp.withlabel = true;
 
     label._setText(function () {
         var digits = Type.evaluate(label.visProp.digits);
@@ -245,7 +270,8 @@ JXG.createSlopeTriangle = function (board, parents, attributes) {
         toppoint: "toppoint",
         label: "label",
         Value: "Value",
-        V: "Value"
+        V: "Value",
+        Direction: "Direction"
     });
 
     el.remove = priv.removeSlopeTriangle;
