@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Carsten Miller,
         Alfred Wassermann
@@ -33,9 +33,9 @@
  * @fileoverview Implementation of smart labels..
  */
 
-import JXG from "../jxg";
-import Const from "../base/constants";
-import Type from "../utils/type";
+import JXG from "../jxg.js";
+import Const from "../base/constants.js";
+import Type from "../utils/type.js";
 
 /**
  * @class Smart label. These are customized text elements for displaying measurements of JSXGraph elements, like length of a
@@ -210,23 +210,43 @@ JXG.createSmartLabel = function (board, parents, attributes) {
 
     } else if (p.elementClass === Const.OBJECT_CLASS_LINE) {
         attr = Type.copyAttributes(attributes, board.options, 'smartlabelline');
+        /**
+         * @class
+         * @ignore
+         */
         attr.rotate = function () { return Math.atan(p.getSlope()) * 180 / Math.PI; };
+        /**
+         * @class
+         * @ignore
+         */
         attr.visible = function () { return (p.L() < 1.5) ? false : true; };
 
     } else if (p.elementClass === Const.OBJECT_CLASS_CIRCLE) {
         attr = Type.copyAttributes(attributes, board.options, 'smartlabelcircle');
+        /**
+         * @class
+         * @ignore
+         */
         attr.visible = function () { return (p.Radius() < 1.5) ? false : true; };
 
     } else if (p.type === Const.OBJECT_TYPE_POLYGON) {
         attr = Type.copyAttributes(attributes, board.options, 'smartlabelpolygon');
     } else if (p.type === Const.OBJECT_TYPE_ANGLE) {
         attr = Type.copyAttributes(attributes, board.options, 'smartlabelangle');
+        /**
+         * @class
+         * @ignore
+         */
         attr.rotate = function () {
             var c1 = p.center.coords.usrCoords,
                 c2 = p.getLabelAnchor().usrCoords,
                 v = Math.atan2(c2[2] - c1[2], c2[1] - c1[1]) * 180 / Math.PI;
             return (v > 90 && v < 270) ? v + 180 : v;
         };
+        /**
+         * @class
+         * @ignore
+         */
         attr.anchorX = function () {
             var c1 = p.center.coords.usrCoords,
                 c2 = p.getLabelAnchor().usrCoords,
@@ -239,27 +259,51 @@ JXG.createSmartLabel = function (board, parents, attributes) {
         var measure;
         switch (mType) {
             case 'length':
+                /**
+                 * @ignore
+                 */
                 measure = function () { return p.L(); };
                 break;
             case 'slope':
+                /**
+                 * @ignore
+                 */
                 measure = function () { return p.Slope(); };
                 break;
             case 'area':
+                /**
+                 * @ignore
+                 */
                 measure = function () { return p.Area(); };
                 break;
             case 'radius':
+                /**
+                 * @ignore
+                 */
                 measure = function () { return p.Radius(); };
                 break;
             case 'perimeter':
+                /**
+                 * @ignore
+                 */
                 measure = function () { return p.Perimeter(); };
                 break;
             case 'rad':
+                /**
+                 * @ignore
+                 */
                 measure = function () { return p.Value(); };
                 break;
             case 'deg':
+                /**
+                 * @ignore
+                 */
                 measure = function () { return p.Value() * 180 / Math.PI; };
                 break;
             default:
+                /**
+                 * @ignore
+                 */
                 measure = function () { return 0.0; };
         }
 
