@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -46,18 +46,23 @@
 
 /**
  * JXG is the top object of JSXGraph and defines the namespace
+ *
+ * @name JXG
  * @exports jxg as JXG
+ * @namespace
  */
 var jxg = {};
 
-// Make sure JXG.extend is not defined
-// If jsxgraph is loaded via loadjsxgraph.js, this is required, but JXG.extend will be undefined
-// If jsxgraph is compiled as an amd module, it is possible that another jsxgraph version is already loaded and we
+// Make sure JXG.extend is not defined.
+// If JSXGraph is compiled as an amd module, it is possible that another JSXGraph version is already loaded and we
 // therefore must not re-use the global JXG variable. But in this case JXG.extend will already be defined.
 // This is the reason for this check.
-if (typeof JXG === "object" && !JXG.extend) {
-    jxg = JXG;
-}
+// The try-statement is necessary, otherwise an error is thrown in certain imports, e.g. in deno.
+try {
+    if (typeof JXG === "object" && !JXG.extend) {
+        jxg = JXG;
+    }
+} catch (e) {}
 
 // We need the following two methods "extend" and "shortcut" to create the JXG object via JXG.extend.
 
@@ -340,7 +345,9 @@ jxg.extend(
          */
         debug: function (s) {
             jxg.debugInt.apply(this, arguments);
-        }
+        },
+
+        themes: {}
     }
 );
 
