@@ -1,10 +1,9 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
         Alfred Wassermann
-console.log("P:", P.coords.usrCoords, P.data.type)
 
     This file is part of JSXGraph.
 
@@ -39,12 +38,12 @@ console.log("P:", P.coords.usrCoords, P.data.type)
  * * Check if input polygons are closed. If not, handle this case.
  */
 
-import JXG from "../jxg";
-import Const from "../base/constants";
-import Coords from "../base/coords";
-import Mat from "./math";
-import Geometry from "./geometry";
-import Type from "../utils/type";
+// import JXG from "../jxg.js";
+import Const from "../base/constants.js";
+import Coords from "../base/coords.js";
+import Mat from "./math.js";
+import Geometry from "./geometry.js";
+import Type from "../utils/type.js";
 
 /**
  * Math.Clip namespace definition. This namespace contains algorithms for Boolean operations on paths, i.e.
@@ -53,11 +52,6 @@ import Type from "../utils/type";
  * @exports Mat.Clip as JXG.Math.Clip
  * @namespace
  */
-// Mat.Clip = function () {
-// };
-
-// JXG.extend(Mat.Clip.prototype, /** @lends JXG.Curve.prototype */ {
-
 Mat.Clip = {
     _isSeparator: function (node) {
         return isNaN(node.coords.usrCoords[1]) && isNaN(node.coords.usrCoords[2]);
@@ -122,7 +116,7 @@ Mat.Clip = {
      * The intersection point is inserted into the doubly linked list of the path.
      *
      * @private
-     * @param  {JXG.Coords} coords JSXGraph Coords object conatining the coordinates of the intersection
+     * @param  {JXG.Coords} coords JSXGraph Coords object containing the coordinates of the intersection
      * @param  {Number} i        Number of the segment of the subject path (first path) containing the intersection.
      * @param  {Number} alpha    The intersection is a p_1 + alpha*(p_2 - p_1), where p_1 and p_2 are the end points
      *      of the i-th segment.
@@ -1515,10 +1509,10 @@ Mat.Clip = {
                 // C is inside of S, i.e. C subset of S
 
                 if (clip_type === "union") {
-                    path = path.concat(S);
+                    Type.concat(path, S);
                     path.push(S[0]);
                 } else if (clip_type === "difference") {
-                    path = path.concat(S);
+                    Type.concat(path, S);
                     path.push(S[0]);
                     if (Geometry.signedPolygon(S) * Geometry.signedPolygon(C) > 0) {
                         // Pathes have same orientation, we have to revert one.
@@ -1527,30 +1521,30 @@ Mat.Clip = {
                     path.push([NaN, NaN]);
                 }
                 if (clip_type === "difference" || clip_type === "intersection") {
-                    path = path.concat(C);
+                    Type.concat(path, C);
                     path.push(C[0]);
                     doClose = false;
                 }
             } else {
                 // The curves are disjoint
                 if (clip_type === "difference") {
-                    path = path.concat(S);
+                    Type.concat(path, S);
                     doClose = true;
                 } else if (clip_type === "union") {
-                    path = path.concat(S);
+                    Type.concat(path, S);
                     path.push(S[0]);
                     path.push([NaN, NaN]);
-                    path = path.concat(C);
+                    Type.concat(path, C);
                     path.push(C[0]);
                 }
             }
         } else {
             // S inside of C, i.e. S subset of C
             if (clip_type === "intersection") {
-                path = path.concat(S);
+                Type.concat(path, S);
                 doClose = true;
             } else if (clip_type === "union") {
-                path = path.concat(C);
+                Type.concat(path, C);
                 path.push(C[0]);
             }
 
@@ -2206,8 +2200,8 @@ Mat.Clip = {
     difference: function (path1, path2, board) {
         return this.greinerHormann(path1, path2, "difference", board);
     }
-}; //);
+};
 
-JXG.extend(Mat.Clip, /** @lends JXG.Math.Clip */ {});
+// JXG.extend(Mat.Clip, /** @lends JXG.Math.Clip */ {});
 
 export default Mat.Clip;
