@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -38,15 +38,16 @@
  * arithmetic functions.
  */
 
-import JXG from "../jxg";
-import Type from "../utils/type";
+import JXG from "../jxg.js";
+import Type from "../utils/type.js";
 
 /**
- * Creates a new complex number.
- * @class This class is for calculating with complex numbers.
+ * Creates a new complex number. See also {@link JXG.C}.
+ * @class This class is for calculating with complex numbers, see also {@link JXG.C} for more methods.
  * @constructor
  * @param {Number} [x=0] Real part.
  * @param {Number} [y=0] Imaginary part.
+ * @see JXG.C
  */
 JXG.Complex = function (x, y) {
     /**
@@ -105,7 +106,7 @@ JXG.extend(
 
         /**
          * Add another complex number to this complex number.
-         * @param {JXG.Complex,Number} c A JavaScript number or a JXG.Complex object to be added to the current object.
+         * @param {JXG.Complex|Number} c A JavaScript number or a JXG.Complex object to be added to the current object.
          * @returns {JXG.Complex} Reference to this complex number
          */
         add: function (c) {
@@ -121,7 +122,7 @@ JXG.extend(
 
         /**
          * Subtract another complex number from this complex number.
-         * @param {JXG.Complex,Number} c A JavaScript number or a JXG.Complex object to subtract from the current object.
+         * @param {JXG.Complex|Number} c A JavaScript number or a JXG.Complex object to subtract from the current object.
          * @returns {JXG.Complex} Reference to this complex number
          */
         sub: function (c) {
@@ -137,7 +138,7 @@ JXG.extend(
 
         /**
          * Multiply another complex number to this complex number.
-         * @param {JXG.Complex,Number} c A JavaScript number or a JXG.Complex object to
+         * @param {JXG.Complex|Number} c A JavaScript number or a JXG.Complex object to
          * multiply with the current object.
          * @returns {JXG.Complex} Reference to this complex number
          */
@@ -161,7 +162,7 @@ JXG.extend(
 
         /**
          * Divide this complex number by the given complex number.
-         * @param {JXG.Complex,Number} c A JavaScript number or a JXG.Complex object to
+         * @param {JXG.Complex|Number} c A JavaScript number or a JXG.Complex object to
          * divide the current object by.
          * @returns {JXG.Complex} Reference to this complex number
          */
@@ -211,6 +212,7 @@ JXG.extend(
 );
 
 /**
+ * @namespace Namespace for the complex number arithmetic functions, see also {@link JXG.Complex}.
  * @description
  * JXG.C is the complex number (name)space. It provides functions to calculate with
  * complex numbers (defined in {@link JXG.Complex}). With this namespace you don't have to modify
@@ -224,14 +226,14 @@ JXG.extend(
  *    var z2 = new JXG.Complex(0, 1);
  *    var z = new JXG.Complex(z1);
  *    z.add(z2);</pre>
- * @namespace Namespace for the complex number arithmetic functions.
+ * @see JXG.Complex
  */
 JXG.C = {};
 
 /**
  * Add two (complex) numbers z1 and z2 and return the result as a (complex) number.
- * @param {JXG.Complex,Number} z1 Summand
- * @param {JXG.Complex,Number} z2 Summand
+ * @param {JXG.Complex|Number} z1 Summand
+ * @param {JXG.Complex|Number} z2 Summand
  * @returns {JXG.Complex} A complex number equal to the sum of the given parameters.
  */
 JXG.C.add = function (z1, z2) {
@@ -242,8 +244,8 @@ JXG.C.add = function (z1, z2) {
 
 /**
  * Subtract two (complex) numbers z1 and z2 and return the result as a (complex) number.
- * @param {JXG.Complex,Number} z1 Minuend
- * @param {JXG.Complex,Number} z2 Subtrahend
+ * @param {JXG.Complex|Number} z1 Minuend
+ * @param {JXG.Complex|Number} z2 Subtrahend
  * @returns {JXG.Complex} A complex number equal to the difference of the given parameters.
  */
 JXG.C.sub = function (z1, z2) {
@@ -254,8 +256,8 @@ JXG.C.sub = function (z1, z2) {
 
 /**
  * Multiply two (complex) numbers z1 and z2 and return the result as a (complex) number.
- * @param {JXG.Complex,Number} z1 Factor
- * @param {JXG.Complex,Number} z2 Factor
+ * @param {JXG.Complex|Number} z1 Factor
+ * @param {JXG.Complex|Number} z2 Factor
  * @returns {JXG.Complex} A complex number equal to the product of the given parameters.
  */
 JXG.C.mult = function (z1, z2) {
@@ -266,8 +268,8 @@ JXG.C.mult = function (z1, z2) {
 
 /**
  * Divide two (complex) numbers z1 and z2 and return the result as a (complex) number.
- * @param {JXG.Complex,Number} z1 Dividend
- * @param {JXG.Complex,Number} z2 Divisor
+ * @param {JXG.Complex|Number} z1 Dividend
+ * @param {JXG.Complex|Number} z2 Divisor
  * @returns {JXG.Complex} A complex number equal to the quotient of the given parameters.
  */
 JXG.C.div = function (z1, z2) {
@@ -278,7 +280,7 @@ JXG.C.div = function (z1, z2) {
 
 /**
  * Conjugate a complex number and return the result.
- * @param {JXG.Complex,Number} z1 Complex number
+ * @param {JXG.Complex|Number} z1 Complex number
  * @returns {JXG.Complex} A complex number equal to the conjugate of the given parameter.
  */
 JXG.C.conj = function (z1) {
@@ -289,7 +291,7 @@ JXG.C.conj = function (z1) {
 
 /**
  * Absolute value of a complex number.
- * @param {JXG.Complex,Number} z1 Complex number
+ * @param {JXG.Complex|Number} z1 Complex number
  * @returns {Number} real number equal to the absolute value of the given parameter.
  */
 JXG.C.abs = function (z1) {
@@ -301,6 +303,16 @@ JXG.C.abs = function (z1) {
     return Math.sqrt(z.real);
 };
 
+/**
+ * Create copy of complex number.
+ *
+ * @param {JXG.Complex|Number} z
+ * @returns {JXG.Complex}
+ */
+JXG.C.copy = function(z) {
+    return new JXG.Complex(z);
+};
+
 JXG.Complex.C = JXG.C;
 
 export default JXG.Complex;
