@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -30,30 +30,30 @@
 /*global JXG: true, define: true*/
 /*jslint nomen: true, plusplus: true*/
 
-import JXG from "../jxg";
-import Mat from "./math";
-import Type from "../utils/type";
+import JXG from "../jxg.js";
+import Mat from "./math.js";
+import Type from "../utils/type.js";
 
 JXG.Math.DoubleBits = function () {
-    var hasTypedArrays = false,
-        DOUBLE_VIEW = new Float64Array(1),
+    var DOUBLE_VIEW = new Float64Array(1),
         UINT_VIEW = new Uint32Array(DOUBLE_VIEW.buffer),
         doubleBitsLE,
         toDoubleLE,
         lowUintLE,
         highUintLE,
+        // doubleBits,
+        // toDouble,
+        // lowUint,
+        // highUint,
+        // hasTypedArrays = false,
         doubleBitsBE,
         toDoubleBE,
         lowUintBE,
-        highUintBE,
-        doubleBits,
-        toDouble,
-        lowUint,
-        highUint;
+        highUintBE;
 
     if (Float64Array !== undefined) {
         DOUBLE_VIEW[0] = 1.0;
-        hasTypedArrays = true;
+        // hasTypedArrays = true;
         if (UINT_VIEW[1] === 0x3ff00000) {
             // Use little endian
             doubleBitsLE = function (n) {
@@ -81,7 +81,7 @@ JXG.Math.DoubleBits = function () {
             this.lo = lowUintLE;
             this.hi = highUintLE;
         } else if (UINT_VIEW[0] === 0x3ff00000) {
-            //Use big endian
+            // Use big endian
             doubleBitsBE = function (n) {
                 DOUBLE_VIEW[0] = n;
                 return [UINT_VIEW[1], UINT_VIEW[0]];
@@ -107,8 +107,8 @@ JXG.Math.DoubleBits = function () {
             this.pack = toDoubleBE;
             this.lo = lowUintBE;
             this.hi = highUintBE;
-        } else {
-            hasTypedArrays = false;
+        // } else {
+        //     hasTypedArrays = false;
         }
     }
 
@@ -1239,6 +1239,17 @@ JXG.Math.IntervalArithmetic = {
         return new MatInterval(lo, hi);
     },
 
+    /**
+     * @param {JXG.Math.Interval} x
+     * @returns JXG.Math.Interval
+     */
+    acot: function (x) {
+        if (this.isEmpty(x)) {
+            return this.EMPTY.clone();
+        }
+        return new MatInterval(this.acotLo(x.lo), this.acotHi(x.hi));
+    },
+
     /**
      * @param {JXG.Math.Interval} x
      * @returns JXG.Math.Interval
@@ -1512,6 +1523,12 @@ JXG.Math.IntervalArithmetic = {
     acosHi: function (x) {
         return this.next(Math.acos(x));
     },
+    acotLo: function (x) {
+        return this.prev(Mat.acot(x));
+    },
+    acotHi: function (x) {
+        return this.next(Mat.acot(x));
+    },
     atanLo: function (x) {
         return this.prev(Math.atan(x));
     },
