@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -36,8 +36,8 @@
  * @fileoverview In this file the namespace JXG.Math is defined, which is the base namespace
  * for namespaces like JXG.Math.Numerics, JXG.Math.Plot, JXG.Math.Statistics, JXG.Math.Clip etc.
  */
-import JXG from "../jxg";
-import Type from "../utils/type";
+import JXG from "../jxg.js";
+import Type from "../utils/type.js";
 
 var undef,
     /*
@@ -71,7 +71,8 @@ var undef,
     };
 
 /**
- * Math namespace.
+ * Math namespace. Contains mathematics related methods which are
+ * specific to JSXGraph or which extend the JavaScript Math class.
  * @namespace
  */
 JXG.Math = {
@@ -109,11 +110,52 @@ JXG.Math = {
     },
 
     /**
-     * Initializes a vector as an array with the coefficients set to the given value resp. zero.
+     * Translate <code>x</code> into the interval <code>[a, b)</code> by adding
+     * a multiple of <code>b - a</code>.
+     * @param {Number} x
+     * @param {Number} a
+     * @param {Number} b
+     */
+    wrap: function (x, a, b) {
+        return a + this.mod(x - a, b - a);
+    },
+
+    /**
+     * Clamp <code>x</code> within the interval <code>[a, b]</code>. If
+     * <code>x</code> is below <code>a</code>, increase it to <code>a</code>. If
+     * it's above <code>b</code>, decrease it to <code>b</code>.
+     */
+    clamp: function (x, a, b) {
+        return Math.min(Math.max(x, a), b);
+    },
+
+    /**
+     * A way of clamping a periodic variable. If <code>x</code> is congruent mod
+     * <code>period</code> to a point in <code>[a, b]</code>, return that point.
+     * Otherwise, wrap it into <code>[mid - period/2, mid + period/2]</code>,
+     * where <code>mid</code> is the mean of <code>a</code> and <code>b</code>,
+     * and then clamp it to <code>[a, b]</code> from there.
+     */
+    wrapAndClamp: function (x, a, b, period) {
+        var mid = 0.5 * (a + b),
+            half_period = 0.5 * period;
+
+        return this.clamp(
+            this.wrap(
+                x,
+                mid - half_period,
+                mid + half_period
+            ),
+            a,
+            b
+        );
+    },
+
+    /**
+     * Initializes a vector of size <tt>n</tt> wih coefficients set to the init value (default 0)
      * @param {Number} n Length of the vector
      * @param {Number} [init=0] Initial value for each coefficient
-     * @returns {Array} A <tt>n</tt> times <tt>m</tt>-matrix represented by a
-     * two-dimensional array. The inner arrays hold the columns, the outer array holds the rows.
+     * @returns {Array} An array of length <tt>n</tt>
      */
     vector: function (n, init) {
         var r, i;
@@ -469,6 +511,14 @@ JXG.Math = {
         return Math.sqrt(sum);
     },
 
+    /**
+     * Compute a * x + y for a scalar a and vectors x and y.
+     *
+     * @param {Number} a
+     * @param {Array} x
+     * @param {Array} y
+     * @returns
+     */
     axpy: function (a, x, y) {
         var i,
             le = x.length,
@@ -740,7 +790,7 @@ JXG.Math = {
      *
      * @function
      * @param  {Number} x A Number
-     * @returns {[type]}  This function has 5 kinds of return values,
+     * @returns {Number}  This function has 5 kinds of return values,
      *    1, -1, 0, -0, NaN, which represent "positive number", "negative number", "positive zero", "negative zero"
      *    and NaN respectively.
      */
@@ -847,6 +897,53 @@ JXG.Math = {
         return 0;
     },
 
+    /**
+     * Special use of Math.round function to round not only to integers but also to chosen decimal values.
+     *
+     * @param {Number} value Value to be rounded.
+     * @param {Number} step Distance between the values to be rounded to. (default: 1.0)
+     * @param {Number} [min] If set, it will be returned the maximum of value and min.
+     * @param {Number} [max] If set, it will be returned the minimum of value and max.
+     * @returns {Number} Fitted value.
+     */
+    roundToStep: function (value, step, min, max) {
+        var n = value,
+            tmp, minOr0;
+
+        // for performance
+        if (!Type.exists(step) && !Type.exists(min) && !Type.exists(max)) {
+            return n;
+        }
+
+        if (JXG.exists(max)) {
+            n = Math.min(n, max);
+        }
+        if (JXG.exists(min)) {
+            n = Math.max(n, min);
+        }
+
+        minOr0 = min || 0;
+
+        if (JXG.exists(step)) {
+            tmp = (n - minOr0) / step;
+            if (Number.isInteger(tmp)) {
+                return n;
+            }
+
+            tmp = Math.round(tmp);
+            n = minOr0 + tmp * step;
+        }
+
+        if (JXG.exists(max)) {
+            n = Math.min(n, max);
+        }
+        if (JXG.exists(min)) {
+            n = Math.max(n, min);
+        }
+
+        return n;
+    },
+
     /**
      *  Error function, see {@link https://en.wikipedia.org/wiki/Error_function}.
      *
@@ -905,6 +1002,74 @@ JXG.Math = {
         return this.ProbFuncs.ndtri(x);
     },
 
+    /**
+     * Returns sqrt(a * a + b * b) for a variable number of arguments.
+     * This is a naive implementation which might be faster than Math.hypot.
+     * The latter is numerically more stable.
+     *
+     * @param {Number} a Variable number of arguments.
+     * @returns Number
+     */
+    hypot: function () {
+        var i, le, a, sum;
+
+        le = arguments.length;
+        for (i = 0, sum = 0.0; i < le; i++) {
+            a = arguments[i];
+            sum += a * a;
+        }
+        return Math.sqrt(sum);
+    },
+
+    /**
+     * Heaviside unit step function. Returns 0 for x &lt;, 1 for x &gt; 0, and 0.5 for x == 0.
+     *
+     * @param {Number} x
+     * @returns Number
+     */
+    hstep: function (x) {
+        return (x > 0.0) ? 1 :
+            ((x < 0.0) ? 0.0 : 0.5);
+    },
+
+    /**
+     * Gamma function for real parameters by Lanczos approximation.
+     * Implementation straight from {@link https://en.wikipedia.org/wiki/Lanczos_approximation}.
+     *
+     * @param {Number} z
+     * @returns Number
+     */
+    gamma: function (z) {
+        var x, y, t, i, le,
+            g = 7,
+            // n = 9,
+            p = [
+                1.0,
+                676.5203681218851,
+                -1259.1392167224028,
+                771.32342877765313,
+                -176.61502916214059,
+                12.507343278686905,
+                -0.13857109526572012,
+                9.9843695780195716e-6,
+                1.5056327351493116e-7
+            ];
+
+        if (z < 0.5) {
+            y = Math.PI / (Math.sin(Math.PI * z) * this.gamma(1 - z));  // Reflection formula
+        } else {
+            z -= 1;
+            x = p[0];
+            le = p.length;
+            for (i = 1; i < le; i++) {
+                x += p[i] / (z + i);
+            }
+            t = z + g + 0.5;
+            y = Math.sqrt(2 * Math.PI) * Math.pow(t, z + 0.5) * Math.exp(-t) * x;
+        }
+        return y;
+    },
+
     /* ********************  Comparisons and logical operators ************** */
 
     /**
@@ -1016,6 +1181,72 @@ JXG.Math = {
         return (a || b) && !(a && b);
     },
 
+    /**
+     *
+     * Convert a floating point number to sign + integer + fraction.
+     * fraction is given as nominator and denominator.
+     * <p>
+     * Algorithm: approximate the floating point number
+     * by a continued fraction and simultaneously keep track
+     * of its convergents.
+     * Inspired by {@link https://kevinboone.me/rationalize.html}.
+     *
+     * @param {Number} x Number which is to be converted
+     * @param {Number} [order=0.001] Small number determining the approximation precision.
+     * @returns {Array} [sign, leading, nominator, denominator] where sign is 1 or -1.
+     * @see JXG#toFraction
+     *
+     * @example
+     * JXG.Math.decToFraction(0.33333333);
+     * // Result: [ 1, 0, 1, 3 ]
+     *
+     * JXG.Math.decToFraction(0);
+     * // Result: [ 1, 0, 0, 1 ]
+     *
+     * JXG.Math.decToFraction(-10.66666666666667);
+     * // Result: [-1, 10, 2, 3 ]
+    */
+    decToFraction: function (x, order) {
+        var lead, sign, a,
+            n, n1, n2,
+            d, d1, d2,
+            it = 0,
+            maxit = 20;
+
+        order = Type.def(order, 0.001);
+
+        // Round the number.
+        // Otherwise, 0.999999999 would result in [0, 1, 1].
+        x = Math.round(x * 1.e12) * 1.e-12;
+
+        // Negative numbers:
+        // The minus sign is handled in sign.
+        sign = (x < 0) ? -1 : 1;
+        x = Math.abs(x);
+
+        // From now on we consider x to be nonnegative.
+        lead = Math.floor(x);
+        x -= Math.floor(x);
+        a = 0.0;
+        n2 = 1.0;
+        n = n1 = a;
+        d2 = 0.0;
+        d = d1 = 1.0;
+
+        while (x - Math.floor(x) > order && it < maxit) {
+            x = 1 / (x - a);
+            a = Math.floor(x);
+            n = n2 + a * n1;
+            d = d2 + a * d1;
+            n2 = n1;
+            d2 = d1;
+            n1 = n;
+            d1 = d;
+            it++;
+        }
+        return [sign, lead, n, d];
+    },
+
     /* *************************** Normalize *************************** */
 
     /**
@@ -1035,7 +1266,7 @@ JXG.Math = {
         stdform[7] = -stdform[2] / a2;
 
         if (!isFinite(r)) {
-            n = Math.sqrt(stdform[1] * stdform[1] + stdform[2] * stdform[2]);
+            n = this.hypot(stdform[1], stdform[2]);
 
             stdform[0] /= n;
             stdform[1] /= n;
