@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -64,8 +64,8 @@
  * by D.E. Knuth and J.D. Hobby.
  */
 
-import Type from "../utils/type";
-import Mat from "./math";
+import Type from "../utils/type.js";
+import Mat from "./math.js";
 
 /**
  * The JXG.Math.Metapost namespace holds algorithms translated from Metapost
@@ -472,7 +472,7 @@ Mat.Metapost = {
      * @private
      */
     mp_pyth_add: function (a, b) {
-        return Math.sqrt(a * a + b * b);
+        return Mat.hypot(a, b);
     },
 
     /**
@@ -752,6 +752,6 @@ Mat.Metapost = {
 
             return [x, y];
         }
-    };
+};
 
-    export default Mat.Metapost;
+export default Mat.Metapost;
