@@ -1,5 +1,5 @@
 /*
- Copyright 2008-2023
+ Copyright 2008-2024
  Matthias Ehmann,
  Carsten Miller,
  Reinhard Oldenburg,
@@ -78,8 +78,9 @@
 /*global JXG: true, define: true*/
 /*jslint nomen: true, plusplus: true, continue: true*/
 
-import JXG from "../jxg";
-// import Type from "../utils/type";
+import JXG from "../jxg.js";
+import Mat from "./math.js";
+// import Type from "../utils/type.js";
 
 /**
  * The JXG.Math.Nlp namespace holds numerical algorithms for non-linear optimization.
@@ -926,7 +927,7 @@ JXG.Math.Nlp = {
                                     this.PART(this.COL(z, k), 1, n),
                                     this.PART(this.COL(a, kk), 1, n)
                                 );
-                                temp = Math.sqrt(sp * sp + zdota[kp] * zdota[kp]);
+                                temp = Mat.hypot(sp, zdota[kp]);
                                 alpha = zdota[kp] / temp;
                                 beta = sp / temp;
                                 zdota[kp] = alpha * zdota[k];
@@ -987,7 +988,7 @@ JXG.Math.Nlp = {
                                 tot = sp;
                             } else {
                                 kp = k + 1;
-                                temp = Math.sqrt(sp * sp + tot * tot);
+                                temp = Mat.hypot(sp, tot);
                                 alpha = sp / temp;
                                 beta = tot / temp;
                                 tot = temp;
@@ -1066,7 +1067,7 @@ JXG.Math.Nlp = {
                                         this.PART(this.COL(z, k), 1, n),
                                         this.PART(this.COL(a, kw), 1, n)
                                     );
-                                    temp = Math.sqrt(sp * sp + zdota[kp] * zdota[kp]);
+                                    temp = Mat.hypot(sp, zdota[kp]);
                                     alpha = zdota[kp] / temp;
                                     beta = sp / temp;
                                     zdota[kp] = alpha * zdota[k];
@@ -1114,7 +1115,7 @@ JXG.Math.Nlp = {
                                 this.PART(this.COL(z, k), 1, n),
                                 this.PART(this.COL(a, kk), 1, n)
                             );
-                            temp = Math.sqrt(sp * sp + zdota[nact] * zdota[nact]);
+                            temp = Mat.hypot(sp, zdota[nact]);
                             alpha = zdota[nact] / temp;
                             beta = sp / temp;
                             zdota[nact] = alpha * zdota[k];
