@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -37,8 +37,8 @@
  * javascript arrays and HTML tables.
  */
 
-import JXG from "../jxg";
-import Type from "../utils/type";
+import JXG from "../jxg.js";
+import Type from "../utils/type.js";
 
 JXG.DataSource = function () {
     this.data = [];
@@ -111,7 +111,7 @@ JXG.extend(
         },
 
         loadFromTable: function (table, columnHeader, rowHeader) {
-            var row, i, j, col, cell, name;
+            var row, i, j, col, cell;
 
             if (Type.isArray(columnHeader)) {
                 this.columnHeaders = columnHeader;
