@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -47,14 +47,14 @@
  * renderers is the class AbstractRenderer defined in this file.
  */
 
-import JXG from "../jxg";
-import Options from "../options";
-import Coords from "../base/coords";
-import Const from "../base/constants";
-import Mat from "../math/math";
-import Geometry from "../math/geometry";
-import Type from "../utils/type";
-import Env from "../utils/env";
+import JXG from "../jxg.js";
+import Options from "../options.js";
+import Coords from "../base/coords.js";
+import Const from "../base/constants.js";
+import Mat from "../math/math.js";
+import Geometry from "../math/geometry.js";
+import Type from "../utils/type.js";
+import Env from "../utils/env.js";
 
 /**
  * <p>This class defines the interface to the graphics part of JSXGraph. This class is an abstract class, it
@@ -213,6 +213,7 @@ JXG.extend(
             if (enhanced || this.enhancedRendering) {
                 not = not || {};
 
+                this.setObjectViewport(el);
                 this.setObjectTransition(el);
                 if (!Type.evaluate(el.visProp.draft)) {
                     if (!not.stroke) {
@@ -381,7 +382,7 @@ JXG.extend(
                         size * 2
                     );
                 } else {
-                    // x, +, <>, ^, v, <, >
+                    // x, +, <>, <<>>, ^, v, <, >
                     this.updatePathPrim(
                         el.rendNode,
                         this.updatePathStringPoint(el, size, face),
@@ -529,7 +530,7 @@ JXG.extend(
             // Get information if there are arrow heads and how large they are.
             arrowData = this.getArrowHeadData(el, w, hl);
 
-            // Create the SVG nodes if neccessary
+            // Create the SVG nodes if necessary
             this.makeArrows(el, arrowData);
 
             // Draw the paths with arrow heads
@@ -1135,9 +1136,9 @@ JXG.extend(
         updateText: function (el) {
             var content = el.plaintext,
                 v, c,
-                parentNode,
-                scale, vshift,
-                id, wrap_id,
+                parentNode, node,
+                // scale, vshift,
+                // id, wrap_id,
                 ax, ay, angle, co, si,
                 to_h, to_v;
 
@@ -1257,31 +1258,50 @@ JXG.extend(
                                     MathJax.Hub.Queue(["Typeset", MathJax.Hub, el.rendNode]);
                                 }
 
-                                // Restore the transformation necessary for fullscreen mode
-                                // MathJax removes it when handling dynamic content
-                                id = el.board.container;
-                                wrap_id = "fullscreenwrap_" + id;
-                                if (document.getElementById(wrap_id)) {
-                                    scale = el.board.containerObj._cssFullscreenStore.scale;
-                                    vshift = el.board.containerObj._cssFullscreenStore.vshift;
-                                    Env.scaleJSXGraphDiv(
-                                        "#" + wrap_id,
-                                        "#" + id,
-                                        scale,
-                                        vshift
-                                    );
-                                }
+                                // Obsolete:
+                                // // Restore the transformation necessary for fullscreen mode
+                                // // MathJax removes it when handling dynamic content
+                                // id = el.board.container;
+                                // wrap_id = "fullscreenwrap_" + id;
+                                // if (document.getElementById(wrap_id)) {
+                                //     scale = el.board.containerObj._cssFullscreenStore.scale;
+                                //     vshift = el.board.containerObj._cssFullscreenStore.vshift;
+                                //     Env.scaleJSXGraphDiv(
+                                //         "#" + wrap_id,
+                                //         "#" + id,
+                                //         scale,
+                                //         vshift
+                                //     );
+                                // }
                             } catch (e) {
                                 JXG.debug("MathJax (not yet) loaded");
                             }
                         } else if (Type.evaluate(el.visProp.usekatex)) {
                             try {
-                                /* eslint-disable no-undef */
-                                katex.render(content, el.rendNode, {
-                                    macros: Type.evaluate(el.visProp.katexmacros),
-                                    throwOnError: false
-                                });
-                                /* eslint-enable no-undef */
+                                // Checkboxes et. al. do not possess rendNodeLabel during the first update.
+                                // In this case node will be undefined and not rendered by KaTeX.
+                                if (el.rendNode.innerHTML.indexOf('<span') === 0 &&
+                                    el.rendNode.innerHTML.indexOf('<label') > 0 &&
+                                    (
+                                        el.rendNode.innerHTML.indexOf('<checkbox') > 0 ||
+                                        el.rendNode.innerHTML.indexOf('<input') > 0
+                                    )
+                                 ) {
+                                    node = el.rendNodeLabel;
+                                } else if (el.rendNode.innerHTML.indexOf('<button') === 0) {
+                                    node = el.rendNodeButton;
+                                } else {
+                                    node = el.rendNode;
+                                }
+
+                                if (node) {
+                                    /* eslint-disable no-undef */
+                                    katex.render(content, node, {
+                                        macros: Type.evaluate(el.visProp.katexmacros),
+                                        throwOnError: false
+                                    });
+                                    /* eslint-enable no-undef */
+                                }
                             } catch (e) {
                                 JXG.debug("KaTeX not loaded (yet)");
                             }
@@ -1450,6 +1470,7 @@ JXG.extend(
 
             this.setObjectTransition(el);
             if (display === "html" && this.type !== "no") {
+                this.setObjectViewport(el, true);
                 // Set new CSS class
                 if (el.visPropOld.cssclass !== css) {
                     el.rendNode.className = css;
@@ -1580,9 +1601,9 @@ JXG.extend(
          * Applies transformations on images and text elements. This method has to implemented in
          * all descendant classes where text and image transformations are to be supported.
          * <p>
-         * Only affine transformation are supported, no proper projective transformations. This means, the 
+         * Only affine transformation are supported, no proper projective transformations. This means, the
          * respective entries of the transformation matrix are simply ignored.
-         * 
+         *
          * @param {JXG.Image|JXG.Text} element A {@link JXG.Image} or {@link JXG.Text} object.
          * @param {Array} transformations An array of {@link JXG.Transformation} objects. This is usually the
          * transformations property of the given element <tt>el</tt>.
@@ -1741,7 +1762,7 @@ JXG.extend(
          * @param {Number} size A positive number describing the size. Usually the half of the width and height of
          * the drawn point.
          * @param {String} type A string describing the point's face. This method only accepts the shortcut version of
-         * each possible face: <tt>x, +, |, -, [], <>, ^, v, >, < </tt>
+         * each possible face: <tt>x, +, |, -, [], <>, <<>>,^, v, >, < </tt>
          */
         updatePathStringPoint: function (element, size, type) {
             /* stub */
@@ -1884,7 +1905,8 @@ JXG.extend(
             var draftColor = el.board.options.elements.draft.color,
                 draftOpacity = el.board.options.elements.draft.opacity;
 
-            this.setObjectTransition(el);
+                this.setObjectViewport(el);
+                this.setObjectTransition(el);
             if (el.type === Const.OBJECT_TYPE_POLYGON) {
                 this.setObjectFillColor(el, draftColor, draftOpacity);
             } else {
@@ -1903,6 +1925,7 @@ JXG.extend(
          * @param {JXG.GeometryElement} el Reference of the object that no longer is in draft mode.
          */
         removeDraft: function (el) {
+            this.setObjectViewport(el);
             this.setObjectTransition(el);
             if (el.type === Const.OBJECT_TYPE_POLYGON) {
                 this.setObjectFillColor(el, el.visProp.fillcolor, el.visProp.fillopacity);
@@ -1943,6 +1966,15 @@ JXG.extend(
             /* stub */
         },
 
+        /**
+         *
+         * @param {*} element
+         * @param {*} isHTML
+         */
+        setObjectViewport: function (element, isHTML) {
+            /* stub */
+        },
+
         /**
          * Sets an objects fill color.
          * @param {JXG.GeometryElement} element Reference of the object that wants a new fill color.
@@ -1999,6 +2031,7 @@ JXG.extend(
                 ev = el.visProp,
                 sw;
 
+            this.setObjectViewport(el);
             this.setObjectTransition(el);
             if (!ev.draft) {
                 if (el.type === Const.OBJECT_TYPE_POLYGON) {
@@ -2073,6 +2106,7 @@ JXG.extend(
                 ev = el.visProp,
                 sw;
 
+            this.setObjectViewport(el);
             this.setObjectTransition(el);
             if (!Type.evaluate(el.visProp.draft)) {
                 if (el.type === Const.OBJECT_TYPE_POLYGON) {
@@ -2162,10 +2196,10 @@ JXG.extend(
                         e.cancelBubble = true;
                     }
                 },
-                createButton = function (label, handler, id) {
+                createButton = function (label, handler, board_id, type) {
                     var button;
 
-                    id = id || "";
+                    board_id = board_id || "";
 
                     button = doc.createElement("span");
                     button.innerHTML = label; // button.appendChild(doc.createTextNode(label));
@@ -2177,10 +2211,11 @@ JXG.extend(
                     if (button.classList !== undefined) {
                         // classList not available in IE 9
                         button.classList.add("JXG_navigation_button");
+                        button.classList.add("JXG_navigation_button_" + type);
                     }
                     // button.setAttribute('tabindex', 0);
 
-                    button.setAttribute("id", id);
+                    button.setAttribute("id", board_id + '_navigation_' + type);
                     node.appendChild(button);
 
                     Env.addEvent(
@@ -2232,7 +2267,7 @@ JXG.extend(
                         function () {
                             board.toFullscreen(board.attr.fullscreen.id);
                         },
-                        board.container + "_navigation_fullscreen"
+                        board.container, "fullscreen"
                     );
                 }
 
@@ -2244,7 +2279,7 @@ JXG.extend(
                                 board.renderer.screenshot(board, "", false);
                             }, 330);
                         },
-                        board.container + "_navigation_screenshot"
+                        board.container, "screenshot"
                     );
                 }
 
@@ -2257,51 +2292,30 @@ JXG.extend(
                         function () {
                             board.reload();
                         },
-                        board.container + "_navigation_reload"
+                        board.container, "reload"
                     );
                 }
 
                 if (board.attr.showcleartraces) {
                     // clear traces symbol (otimes): \u27F2
-                    createButton(
-                        "\u2297",
+                    createButton("\u2297",
                         function () {
                             board.clearTraces();
                         },
-                        board.container + "_navigation_cleartraces"
+                        board.container, "cleartraces"
                     );
                 }
 
                 if (board.attr.shownavigation) {
                     if (board.attr.showzoom) {
-                        createButton(
-                            "\u2013",
-                            board.zoomOut,
-                            board.container + "_navigation_out"
-                        );
-                        createButton("o", board.zoom100, board.container + "_navigation_100");
-                        createButton("+", board.zoomIn, board.container + "_navigation_in");
+                        createButton("\u2013", board.zoomOut, board.container, "out");
+                        createButton("o", board.zoom100, board.container, "100");
+                        createButton("+", board.zoomIn, board.container, "in");
                     }
-                    createButton(
-                        "\u2190",
-                        board.clickLeftArrow,
-                        board.container + "_navigation_left"
-                    );
-                    createButton(
-                        "\u2193",
-                        board.clickUpArrow,
-                        board.container + "_navigation_down"
-                    ); // Down arrow
-                    createButton(
-                        "\u2191",
-                        board.clickDownArrow,
-                        board.container + "_navigation_up"
-                    ); // Up arrow
-                    createButton(
-                        "\u2192",
-                        board.clickRightArrow,
-                        board.container + "_navigation_right"
-                    );
+                    createButton("\u2190", board.clickLeftArrow, board.container, "left");
+                    createButton("\u2193", board.clickUpArrow, board.container, "down"); // Down arrow
+                    createButton("\u2191", board.clickDownArrow, board.container, "up"); // Up arrow
+                    createButton("\u2192", board.clickRightArrow, board.container, "right");
                 }
             }
         },
