@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -32,18 +32,18 @@
 /*global JXG: true, define: true, AMprocessNode: true, document: true, Image: true, module: true, require: true */
 /*jslint nomen: true, plusplus: true, newcap:true*/
 
-import JXG from "../jxg";
-import AbstractRenderer from "./abstract";
-import Const from "../base/constants";
-import Env from "../utils/env";
-import Type from "../utils/type";
-import UUID from "../utils/uuid";
-import Color from "../utils/color";
-import Coords from "../base/coords";
-import Mat from "../math/math";
-import Geometry from "../math/geometry";
-import Numerics from "../math/numerics";
-// import $__canvas from "canvas";
+import JXG from "../jxg.js";
+import AbstractRenderer from "./abstract.js";
+import Const from "../base/constants.js";
+import Env from "../utils/env.js";
+import Type from "../utils/type.js";
+import UUID from "../utils/uuid.js";
+import Color from "../utils/color.js";
+import Coords from "../base/coords.js";
+import Mat from "../math/math.js";
+import Geometry from "../math/geometry.js";
+import Numerics from "../math/numerics.js";
+// import $__canvas from "canvas.js";
 
 /**
  * Uses HTML Canvas to implement the rendering methods defined in {@link JXG.AbstractRenderer}.
@@ -89,7 +89,7 @@ JXG.CanvasRenderer = function (container, dim) {
             throw new Error('JXG.createCanvas not available.\n' +
                 'Install the npm package `canvas`\n' +
                 'and call:\n' +
-                '    import { createCanvas } from "canvas";\n' +
+                '    import { createCanvas } from "canvas.js";\n' +
                 '    JXG.createCanvas = createCanvas;\n');
         }
     }
@@ -307,12 +307,12 @@ JXG.extend(
         // documented in JXG.AbstractRenderer
         updateGradient: function (el) {
             var col,
-                op,
+                // op,
                 ev_g = Type.evaluate(el.visProp.gradient),
                 gradient;
 
-            op = Type.evaluate(el.visProp.fillopacity);
-            op = op > 0 ? op : 0;
+            // op = Type.evaluate(el.visProp.fillopacity);
+            // op = op > 0 ? op : 0;
             col = Type.evaluate(el.visProp.fillcolor);
 
             if (ev_g === "linear") {
@@ -565,6 +565,10 @@ JXG.extend(
                     context.closePath();
                     this._stroke(el);
                     break;
+                /* eslint-disable no-fallthrough */
+                case "diamond2":
+                case "<<>>":
+                    size *= 1.41;
                 case "diamond": // <>
                 case "<>":
                     context.beginPath();
@@ -576,6 +580,7 @@ JXG.extend(
                     this._fill(el);
                     this._stroke(el);
                     break;
+                /* eslint-enable no-fallthrough */
                 case "triangleup":
                 case "A":
                 case "a":
@@ -1600,11 +1605,11 @@ JXG.extend(
 
         // documented in AbstractRenderer
         setGradient: function (el) {
-            var // col,
-                op;
+            // var // col,
+            //     op;
 
-            op = Type.evaluate(el.visProp.fillopacity);
-            op = op > 0 ? op : 0;
+            // op = Type.evaluate(el.visProp.fillopacity);
+            // op = op > 0 ? op : 0;
 
             // col = Type.evaluate(el.visProp.fillcolor);
         },
@@ -1687,7 +1692,7 @@ JXG.extend(
             }
             this.context = this.canvasRoot.getContext("2d");
             // The width and height of the canvas is set to twice the CSS values,
-            // followed by an appropiate scaling.
+            // followed by an appropriate scaling.
             // See https://stackoverflow.com/questions/22416462/canvas-element-with-blurred-lines
             this.context.scale(2, 2);
         },
