@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -41,8 +41,8 @@
  * renderers is the class AbstractRenderer.
  */
 
-import JXG from "../jxg";
-import AbstractRenderer from "./abstract";
+import JXG from "../jxg.js";
+import AbstractRenderer from "./abstract.js";
 
 /**
  * This renderer draws nothing. It is intended to be used in environments where none of our rendering engines
@@ -461,7 +461,7 @@ JXG.extend(
          * @param {Number} size A positive number describing the size. Usually the half of the width and height of
          * the drawn point.
          * @param {String} type A string describing the point's face. This method only accepts the shortcut version of
-         * each possible face: <tt>x, +, |, -, [], <>, ^, v, >, <
+         * each possible face: <tt>x, +, |, -, [], <>, <<>>, ^, v, >, <
          */
         updatePathStringPoint: function (element, size, type) {
             /* stub */
