@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -39,9 +39,9 @@
  * Stoyan Stefanov <sstoo@gmail.com> (see https://www.phpied.com/rgb-color-parser-in-javascript/)
  */
 
-import JXG from "../jxg";
-import Type from "./type";
-import Mat from "../math/math";
+import JXG from "../jxg.js";
+import Type from "./type.js";
+import Mat from "../math/math.js";
 
 // private constants and helper functions
 
@@ -232,7 +232,7 @@ var simpleColors = {
  * Converts a valid HTML/CSS color string into a rgb value array. This is the base
  * function for the following wrapper functions which only adjust the output to
  * different flavors like an object, string or hex values.
- * @param {String,Array,Number} color A valid HTML or CSS styled color value, e.g. '#12ab21', '#abc', 'black',
+ * @param {String|Array|Number} color A valid HTML or CSS styled color value, e.g. '#12ab21', '#abc', 'black'
  * or 'rgb(12, 132, 233)'. This can also be an array containing three color values either from 0.0 to 1.0 or
  * from 0 to 255. They will be interpreted as red, green, and blue values. In case this is a number this method
  * expects the parameters ag and ab.
@@ -291,7 +291,7 @@ JXG.rgbParser = function (color, ag, ab) {
     // strip any leading #
     if (color_string.charAt(0) === "#") {
         // remove # if any
-        color_string = color_string.substr(1, 6);
+        color_string = color_string.slice(1, 7);
     }
 
     color_string = color_string.replace(/ /g, "").toLowerCase();
@@ -326,9 +326,15 @@ JXG.rgbParser = function (color, ag, ab) {
     return [r, g, b];
 };
 
+JXG.isColor = function (strColor) {
+    var s = new Option().style;
+    s.color = strColor;
+    return s.color !== '';
+};
+
 /**
  * Converts a valid HTML/CSS color string into a string of the 'rgb(r, g, b)' format.
- * @param {String,Array,Number} color A valid HTML or CSS styled color value, e.g. '#12ab21', '#abc', 'black',
+ * @param {String|Array|Number} color A valid HTML or CSS styled color value, e.g. '#12ab21', '#abc', 'black'
  * or 'rgb(12, 132, 233)'. This can also be an array containing three color values either from 0.0 to 1.0 or
  * from 0 to 255. They will be interpreted as red, green, and blue values. In case this is a number this method
  * expects the parameters ag and ab.
@@ -346,7 +352,7 @@ JXG.rgb2css = function (color, ag, ab) {
 
 /**
  * Converts a valid HTML/CSS color string into a HTML rgb string.
- * @param {String,Array,Number} color A valid HTML or CSS styled color value, e.g. '#12ab21', '#abc', 'black',
+ * @param {String|Array|Number} color A valid HTML or CSS styled color value, e.g. '#12ab21', '#abc', 'black'
  * or 'rgb(12, 132, 233)'. This can also be an array containing three color values either from 0.0 to 1.0 or
  * from 0 to 255. They will be interpreted as red, green, and blue values. In case this is a number this method
  * expects the parameters ag and ab.
@@ -477,7 +483,7 @@ JXG.hsv2rgb = function (H, S, V) {
 
 /**
  * Converts a color from the RGB color space into the HSV space. Input can be any valid HTML/CSS color definition.
- * @param {String,Array,Number} color A valid HTML or CSS styled color value, e.g. '#12ab21', '#abc', 'black',
+ * @param {String|Array|Number} color A valid HTML or CSS styled color value, e.g. '#12ab21', '#abc', 'black'
  * or 'rgb(12, 132, 233)'. This can also be an array containing three color values either from 0.0 to 1.0 or
  * from 0 to 255. They will be interpreted as red, green, and blue values. In case this is a number this method
  * expects the parameters ag and ab.
@@ -536,7 +542,7 @@ JXG.rgb2hsv = function (color, ag, ab) {
 
 /**
  * Converts a color from the RGB color space into the LMS space. Input can be any valid HTML/CSS color definition.
- * @param {String,Array,Number} color A valid HTML or CSS styled color value, e.g. '#12ab21', '#abc', 'black',
+ * @param {String|Array|Number} color A valid HTML or CSS styled color value, e.g. '#12ab21', '#abc', 'black'
  * or 'rgb(12, 132, 233)'. This can also be an array containing three color values either from 0.0 to 1.0 or
  * from 0 to 255. They will be interpreted as red, green, and blue values. In case this is a number this method
  * expects the parameters ag and ab.
@@ -660,8 +666,8 @@ JXG.rgba2rgbo = function (rgba) {
     var opacity;
 
     if (rgba.length === 9 && rgba.charAt(0) === "#") {
-        opacity = parseInt(rgba.substr(7, 2).toUpperCase(), 16) / 255;
-        rgba = rgba.substr(0, 7);
+        opacity = parseInt(rgba.slice(7, 9).toUpperCase(), 16) / 255;
+        rgba = rgba.slice(0, 7);
     } else {
         opacity = 1;
     }
@@ -671,14 +677,16 @@ JXG.rgba2rgbo = function (rgba) {
 
 /**
  * Generates a RGBA color value like #112233AA from it's RGB and opacity parts.
- * @param {String} rgb A RGB color value.
+ * @param {String|Array} rgb A valid HTML or CSS styled color value, e.g. '#12ab21', '#abc', 'black'
+ * or 'rgb(12, 132, 233)'. This can also be an array containing three color values either from 0.0 to 1.0 or
+ * from 0 to 255. They will be interpreted as red, green, and blue values.
  * @param {Number} o The desired opacity >=0, <=1.
  * @returns {String} The RGBA color value.
  */
 JXG.rgbo2rgba = function (rgb, o) {
     var rgba;
 
-    if (rgb === "none") {
+    if (rgb === "none" || rgb === "transparent") {
         return rgb;
     }
 
@@ -687,7 +695,7 @@ JXG.rgbo2rgba = function (rgb, o) {
         rgba = "0" + rgba;
     }
 
-    return rgb + rgba;
+    return JXG.rgb2hex(rgb) + rgba;
 };
 
 /**
@@ -821,6 +829,61 @@ JXG.rgb2cb = function (color, deficiency) {
     return color;
 };
 
+/**
+ * Lightens (percent > 0) or darkens (percent < 0) the color by the specified factor.
+ * @param {String} color
+ * @param {Number} percent
+ * @returns {String}
+ */
+JXG.shadeColor = function (color, percent) {
+    var arr = JXG.rgbParser(color),
+        r = arr[0],
+        g = arr[1],
+        b = arr[2];
+
+    r = parseInt(r + 255 * percent);
+    g = parseInt(g + 255 * percent);
+    b = parseInt(b + 255 * percent);
+
+    r = (r > 0) ? r : 0;
+    g = (g > 0) ? g : 0;
+    b = (b > 0) ? b : 0;
+
+    r = (r < 255) ? r : 255;
+    g = (g < 255) ? g : 255;
+    b = (b < 255) ? b : 255;
+
+    r = Math.round(r);
+    g = Math.round(g);
+    b = Math.round(b);
+
+    return JXG.rgb2hex([r, g, b]);
+};
+
+/**
+ * Lightens the color by the specified factor.
+ * @param {String} color
+ * @param {Number} percent
+ * @returns {String}
+ *
+ * @see JXG.shadeColor
+ */
+JXG.lightenColor = function (color, percent) {
+    return JXG.shadeColor(color, percent);
+};
+
+/**
+ * Darkens the color by the specified factor.
+ * @param {String} color
+ * @param {Number} percent
+ * @returns {String}
+ *
+ * @see JXG.shadeColor
+ */
+JXG.darkenColor = function (color, percent) {
+    return JXG.shadeColor(color, -1 * percent);
+};
+
 /**
  * Determines highlight color to a given color. Done by reducing (or increasing) the opacity.
  * @param {String} color HTML RGBA string containing the HTML color code.
