@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -36,8 +36,8 @@
  * @fileoverview The JXG.Dump namespace provides methods to save a board to javascript.
  */
 
-import JXG from "../jxg";
-import Type from "./type";
+import JXG from "../jxg.js";
+import Type from "./type.js";
 
 /**
  * The JXG.Dump namespace provides classes and methods to save a board to javascript.
@@ -106,7 +106,7 @@ JXG.Dump = {
      * @returns {String} " + s + "
      */
     str: function (s) {
-        if (typeof s === "string" && s.substr(0, 7) !== "function") {
+        if (typeof s === "string" && s.slice(0, 7) !== "function") {
             s = '"' + s + '"';
         }
 
