@@ -13,7 +13,7 @@
 /*global JXG: true, define: true*/
 /*jslint nomen: true, plusplus: true, bitwise: true*/
 
-import JXG from "../jxg";
+import JXG from "../jxg.js";
 
 // constants
 var uuidCharsStr = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz",
@@ -33,7 +33,7 @@ JXG.Util.genUUID = function (prefix) {
 
     prefix = prefix || "";
 
-    if (prefix !== "" && prefix.substr(prefix.length - 1) !== "-") {
+    if (prefix !== "" && prefix.slice(prefix.length - 1) !== "-") {
         prefix = prefix + "-";
     }
 
