@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2023
+    Copyright 2008-2024
         Matthias Ehmann,
         Carsten Miller,
         Andreas Walter,
@@ -41,6 +41,7 @@ describe("Test board events", function () {
         axis: false,
         grid: false,
         boundingbox: [0, 5, 5, 0],
+        resize: {enabled: false},
         keyboard: {
             enabled: true,
             dy: 20,
@@ -89,14 +90,14 @@ describe("Test board events", function () {
         evt = new PointerEvent("pointerdown", {
             pointerId: pointerId,
             clientX: 1,
-            clientY: 499
+            clientY: 495
         });
         board.pointerDownListener(evt);
 
         evt = new PointerEvent("pointermove", {
             pointerId: pointerId,
             clientX: 201,
-            clientY: 499
+            clientY: 495
         });
         board.pointerMoveListener(evt);
         board.pointerUpListener(evt);
