@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2022
+    Copyright 2008-2024
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -25,12 +25,12 @@
     GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public License and
-    the MIT License along with JSXGraph. If not, see <http://www.gnu.org/licenses/>
-    and <http://opensource.org/licenses/MIT/>.
+    the MIT License along with JSXGraph. If not, see <https://www.gnu.org/licenses/>
+    and <https://opensource.org/licenses/MIT/>.
  */
 
 describe("Test JXG.Math.Poly", function () {
-    var r = new JXG.Math.Poly.Ring(['x', 'y', 'z']),
+    var r = new JXG.Math.Poly.Ring(["x", "y", "z"]),
         m = new JXG.Math.Poly.Monomial(r, 4, [1, 2, 3]),
         p = new JXG.Math.Poly.Polynomial(r);
 
