@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2022
+    Copyright 2008-2024
         Matthias Ehmann,
         Carsten Miller,
         Andreas Walter,
@@ -23,15 +23,17 @@
     GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public License and
-    the MIT License along with JSXGraph. If not, see <http://www.gnu.org/licenses/>
-    and <http://opensource.org/licenses/MIT/>.
+    the MIT License along with JSXGraph. If not, see <https://www.gnu.org/licenses/>
+    and <https://opensource.org/licenses/MIT/>.
  */
-describe("Test JXG.Mat.Statistics", function() {
-
-    it("Percentiles", function() {
-        var data = [57, 57, 57, 58, 63, 66, 66, 67, 67, 68, 69, 70, 70, 70, 70, 72, 73, 75, 75, 76, 76, 78, 79, 81];
+describe("Test JXG.Mat.Statistics", function () {
+    it("Percentiles", function () {
+        var data = [
+            57, 57, 57, 58, 63, 66, 66, 67, 67, 68, 69, 70, 70, 70, 70, 72, 73, 75, 75, 76, 76,
+            78, 79, 81
+        ];
         expect(JXG.Math.Statistics.min(data)).toEqual(57);
         expect(JXG.Math.Statistics.max(data)).toEqual(81);
         expect(JXG.Math.Statistics.percentile(data, [25, 50, 75])).toEqual([66, 70, 75]);
     });
-});
\ No newline at end of file
+});
